(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    517075,       9996]
NotebookOptionsPosition[    511721,       9818]
NotebookOutlinePosition[    512157,       9835]
CellTagsIndexPosition[    512114,       9832]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Test of Model Predictions", "Title"],

Cell["\<\
This Notebook shows how REAP can be used to test how the predictions of a \
given model change during the RG evolution to low energy.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"$VersionNumber", "<", "6"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Get", "[", "\"\<Graphics`FilledPlot`\>\"", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Get", "[", "\"\<Graphics`Colors`\>\"", "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ForestGreen", "=", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0.1", ",", "0.75", ",", "0.2"}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.435587848557613*^9, 3.435587856517888*^9}, {
  3.435655531948548*^9, 3.435655544087432*^9}, {3.635817659548285*^9, 
  3.6358176642028017`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<REAP`RGEMSSM`\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Needs", "[", "\"\<REAP`RGEPlotUtilities`\>\"", "]"}], 
  ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MZ", "=", "91.12"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GUT", "=", 
   RowBox[{"2", " ", 
    RowBox[{"10", "^", "16"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6368469804624157`*^9, 3.63684698357728*^9}}],

Cell["\<\
RGEReset is used in order to set all variables of RGESolver to their default \
values, if the notebook is executed several times.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RGEReset", "[", "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Definition of the model", "Section"],

Cell["\<\
We assume a supersymmetric model.  Below the SUSY-breaking scale (taken to be \
1 TeV), the SM is used as an effective theory.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"RGEReset", "[", "]"}]], "Input",
 CellChangeTimes->{{3.635818682949304*^9, 3.63581868546563*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RGEAdd", "[", 
   RowBox[{"\"\<MSSM\>\"", ",", 
    RowBox[{"RGEtan\[Beta]", "\[Rule]", "50"}], ",", 
    RowBox[{"RGESearchTransitions", "\[Rule]", "True"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RGEAdd", "[", 
   RowBox[{"\"\<SM\>\"", ",", 
    RowBox[{"RGECutoff", "\[Rule]", "1000"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6358186882106533`*^9, 3.635818699794078*^9}}],

Cell[TextData[{
 "All couplings are given explicitly and no default values of the REAP \
package are used. The Yukawa couplings are given in \"RL convention\".  The \
neutrino masses are determined by ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Y", "\[Nu]"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox["M", TraditionalForm]]],
 ".\n\[Kappa] is set to 0. In a type II see-saw scenario, \[Kappa] is \
different from 0 below the mass threshold of the Higgs triplet."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RGESetInitial", "[", 
   RowBox[{"GUT", ",", "\[IndentingNewLine]", 
    RowBox[{"RGEg1", "\[Rule]", "0.7044"}], ",", "\[IndentingNewLine]", 
    RowBox[{"RGEg2", "\[Rule]", "0.6965"}], ",", "\[IndentingNewLine]", 
    RowBox[{"RGEg3", "\[Rule]", "0.6984"}], ",", "\[IndentingNewLine]", 
    RowBox[{"RGEYu", "\[Rule]", 
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {
         RowBox[{"5.980", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "6"}]]}], "0", "0"},
        {"0", "0.001736", "0"},
        {"0", "0", "0.7417"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}],
     ",", "\[IndentingNewLine]", 
    RowBox[{"RGEYd", "\[Rule]", 
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0.0007314", 
         RowBox[{"0.001558", "\[InvisibleSpace]", "+", 
          RowBox[{"0.000022", " ", "\[ImaginaryI]"}]}], 
         RowBox[{"0.0002393", "\[InvisibleSpace]", "+", 
          RowBox[{"0.0006778", " ", "\[ImaginaryI]"}]}]},
        {
         RowBox[{"0.001555", "\[InvisibleSpace]", "-", 
          RowBox[{"0.000022", "\[ImaginaryI]"}]}], 
         RowBox[{"0.007555", "\[InvisibleSpace]"}], 
         RowBox[{"0.008913", "\[InvisibleSpace]", "-", 
          RowBox[{"0.000004", " ", "\[ImaginaryI]"}]}]},
        {
         RowBox[{"0.0002393", "\[InvisibleSpace]", "-", 
          RowBox[{"0.0006778", " ", "\[ImaginaryI]"}]}], 
         RowBox[{"0.008913", "\[InvisibleSpace]", "+", 
          RowBox[{"0.000004", " ", "\[ImaginaryI]"}]}], "0.2872"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}],
     ",", "\[IndentingNewLine]", 
    RowBox[{"RGEYe", "\[Rule]", 
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0.00009344", "0", "0"},
        {"0", "0.01972", "0"},
        {"0", "0", "0.33678"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}],
     ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"RGEY\[Nu]", "\[Rule]", 
     RowBox[{"0.5", " ", 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0.01", "0", "0"},
         {
          RowBox[{"0.0001", "\[ImaginaryI]"}], "0.1", "0"},
         {"0", "0", "1"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
       ")"}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"RGE\[Kappa]", "\[Rule]", 
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0", "0", "0"},
        {"0", "0", "0"},
        {"0", "0", "0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}],
     ",", "\[IndentingNewLine]", 
    RowBox[{"RGEM\[Nu]r", "\[Rule]", 
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {
         RowBox[{
          RowBox[{"-", "3.660"}], " ", 
          SuperscriptBox["10", "10"]}], 
         RowBox[{"1.675", " ", 
          SuperscriptBox["10", "10"]}], 
         RowBox[{
          RowBox[{"-", "1.675"}], " ", 
          SuperscriptBox["10", "11"]}]},
        {
         RowBox[{"1.675", " ", 
          SuperscriptBox["10", "10"]}], 
         RowBox[{
          RowBox[{"-", "2.218"}], " ", 
          SuperscriptBox["10", "12"]}], 
         RowBox[{"1.098", " ", 
          SuperscriptBox["10", "13"]}]},
        {
         RowBox[{
          RowBox[{"-", "1.675"}], " ", 
          SuperscriptBox["10", "11"]}], 
         RowBox[{"1.098", " ", 
          SuperscriptBox["10", "13"]}], 
         RowBox[{
          RowBox[{"-", "2.218"}], " ", 
          SuperscriptBox["10", "14"]}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
      ")"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RGESolve", "[", 
   RowBox[{"MZ", ",", "GUT"}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots", "Section"],

Cell[CellGroupData[{

Cell["Definitions", "Subsection"],

Cell["Define the plot region", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{"tmin", ",", "tmax"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmin", "=", 
   RowBox[{"Log", "[", 
    RowBox[{"10", ",", "MZ"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{"Log", "[", 
    RowBox[{"10", ",", "GUT"}], "]"}]}], ";"}]}], "Input"],

Cell["Define the functions that should be plotted", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{"Mnu", ",", "Ye"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mnu", "[", "mu_", "]"}], ":=", 
  RowBox[{
   RowBox[{"RGEGetSolution", "[", 
    RowBox[{"mu", ",", "RGEM\[Nu]"}], "]"}], "//", 
   "Chop"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ye", "[", "mu_", "]"}], ":=", 
   RowBox[{
    RowBox[{"RGEGetSolution", "[", 
     RowBox[{"mu", ",", "RGEYe"}], "]"}], "//", "Chop"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ClearAll", "[", 
  RowBox[{
  "MixingPars", ",", "MixingParsLogScale", ",", "NuMasses", ",", 
   "NuMassesLogScale"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MixingPars", "[", "mu_", "]"}], ":=", 
  RowBox[{
   RowBox[{"MNSParameters", "[", 
    RowBox[{
     RowBox[{"Mnu", "[", "mu", "]"}], ",", 
     RowBox[{"Ye", "[", "mu", "]"}]}], "]"}], "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\n", 
 RowBox[{
  RowBox[{"MixingParsLogScale", "[", "x_", "]"}], ":=", 
  RowBox[{"MixingPars", "[", 
   RowBox[{"10", "^", "x"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"NuMasses", "[", "mu_", "]"}], ":=", 
  RowBox[{
   RowBox[{"MNSParameters", "[", 
    RowBox[{
     RowBox[{"Mnu", "[", "mu", "]"}], ",", 
     RowBox[{"Ye", "[", "mu", "]"}]}], "]"}], "\[LeftDoubleBracket]", "2", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NuMassesLogScale", "[", "x_", "]"}], ":=", 
   RowBox[{"NuMasses", "[", 
    RowBox[{"10", "^", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ClearAll", "[", 
  RowBox[{
  "\[Theta]12", ",", "\[Theta]13", ",", "\[Theta]23", ",", "\[Delta]", ",", 
   "\[CurlyPhi]1", ",", "\[CurlyPhi]2", ",", "m1", ",", "m2", ",", "m3", ",", 
   "\[CapitalDelta]m2sol", ",", "\[CapitalDelta]m2atm"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]12", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"MixingParsLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", 
    "1", "\[RightDoubleBracket]"}], "/", "Degree"}]}], "\n", 
 RowBox[{
  RowBox[{"\[Theta]13", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"MixingParsLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", 
    "2", "\[RightDoubleBracket]"}], "/", "Degree"}]}], "\n", 
 RowBox[{
  RowBox[{"\[Theta]23", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"MixingParsLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", 
    "3", "\[RightDoubleBracket]"}], "/", 
   "Degree"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"MixingParsLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", 
    "4", "\[RightDoubleBracket]"}], "/", "Degree"}]}], "\n", 
 RowBox[{
  RowBox[{"\[CurlyPhi]1", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"MixingParsLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", 
    "8", "\[RightDoubleBracket]"}], "/", 
   "Degree"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CurlyPhi]2", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"MixingParsLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", 
    "9", "\[RightDoubleBracket]"}], "/", 
   "Degree"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m1", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{"NuMassesLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\n", 
 RowBox[{
  RowBox[{"m2", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{"NuMassesLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", "2", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m3", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{"NuMassesLogScale", "[", "t", "]"}], "\[LeftDoubleBracket]", "3", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalDelta]m2sol", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"m2", "[", "t", "]"}], "^", "2"}], "-", 
   RowBox[{
    RowBox[{"m1", "[", "t", "]"}], "^", "2"}]}]}], "\n", 
 RowBox[{
  RowBox[{"\[CapitalDelta]m2atm", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"m3", "[", "t", "]"}], "^", "2"}], "-", 
   RowBox[{
    RowBox[{"m2", "[", "t", "]"}], "^", 
    "2"}]}]}], "\[IndentingNewLine]"}], "Input"],

Cell["\<\
Test for compatibility with the experimental data
(allowed regions at the 3\[Sigma] CL as given in Maltoni et al., \
hep-ph/0405172v4)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{"CompareToExperiment", ",", "IsCompatibleWithExp"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CompareToExperiment", "[", "t_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lNotComp", ",", "lComp"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"lComp", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"lNotComp", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"\[Theta]12", "[", "t", "]"}], " ", "Degree"}], "]"}], 
           "^", "2"}], "\[GreaterEqual]", "0.23"}], "&&", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"\[Theta]12", "[", "t", "]"}], " ", "Degree"}], "]"}], 
           "^", "2"}], "\[LessEqual]", "0.38"}]}], ",", 
        RowBox[{"lComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lComp", ",", "\"\<\[Theta]12\>\""}], "]"}]}], ",", 
        RowBox[{"lNotComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lNotComp", ",", "\"\<\[Theta]12\>\""}], "]"}]}]}], "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"\[Theta]13", "[", "t", "]"}], " ", "Degree"}], "]"}], 
          "^", "2"}], "\[LessEqual]", "0.051"}], ",", 
        RowBox[{"lComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lComp", ",", "\"\<\[Theta]13\>\""}], "]"}]}], ",", 
        RowBox[{"lNotComp", "[", 
         RowBox[{"lNotComp", ",", "\"\<\[Theta]13\>\""}], "]"}]}], "]"}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"\[Theta]23", "[", "t", "]"}], " ", "Degree"}], "]"}], 
           "^", "2"}], "\[GreaterEqual]", "0.34"}], "&&", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"\[Theta]23", "[", "t", "]"}], " ", "Degree"}], "]"}], 
           "^", "2"}], "\[LessEqual]", "0.68"}]}], ",", 
        RowBox[{"lComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lComp", ",", "\"\<\[Theta]23\>\""}], "]"}]}], ",", 
        RowBox[{"lNotComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lNotComp", ",", "\"\<\[Theta]23\>\""}], "]"}]}]}], "]"}], 
      ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"\[CapitalDelta]m2atm", "[", "t", "]"}], "]"}], 
          "\[GreaterEqual]", 
          RowBox[{"1.3", " ", 
           RowBox[{"10", "^", 
            RowBox[{"-", "3"}]}]}]}], "&&", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"\[CapitalDelta]m2atm", "[", "t", "]"}], "]"}], 
          "\[LessEqual]", 
          RowBox[{"3.2", " ", 
           RowBox[{"10", "^", 
            RowBox[{"-", "3"}]}]}]}]}], ",", 
        RowBox[{"lComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lComp", ",", "\"\<\[CapitalDelta]m2atm\>\""}], "]"}]}], 
        ",", 
        RowBox[{"lNotComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lNotComp", ",", "\"\<\[CapitalDelta]m2atm\>\""}], 
          "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalDelta]m2sol", "[", "t", "]"}], "\[GreaterEqual]", 
          
          RowBox[{"7.1", " ", 
           RowBox[{"10", "^", 
            RowBox[{"-", "5"}]}]}]}], "&&", 
         RowBox[{
          RowBox[{"\[CapitalDelta]m2sol", "[", "t", "]"}], "\[LessEqual]", 
          RowBox[{"8.9", " ", 
           RowBox[{"10", "^", 
            RowBox[{"-", "5"}]}]}]}]}], ",", 
        RowBox[{"lComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lComp", ",", "\"\<\[CapitalDelta]m2sol\>\""}], "]"}]}], 
        ",", 
        RowBox[{"lNotComp", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lNotComp", ",", "\"\<\[CapitalDelta]m2sol\>\""}], 
          "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<The following parameters are compatible with the experimental \
data at the 3\[Sigma] CL:\>\"", ",", "lComp"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "lNotComp", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", "1", "]"}], ",", 
        RowBox[{"Return", "[", "0", "]"}]}], "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\n", 
 RowBox[{"IsCompatibleWithExp", ":=", 
  RowBox[{"CompareToExperiment", "[", 
   RowBox[{"Log", "[", 
    RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}]}], "Input"],

Cell["Positions of the thresholds", "Text"],

Cell[BoxData[{
 RowBox[{"ClearAll", "[", 
  RowBox[{"M1", ",", "M2", ",", "M3", ",", "ShadowEFT"}], "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"M1", ",", "M2", ",", "M3"}], "}"}], "=", 
   RowBox[{
    RowBox[{"RGEGetTransitions", "[", "]"}], "\[LeftDoubleBracket]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "3", ",", "2"}], "}"}], ",", "1"}], 
    "\[RightDoubleBracket]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ShadowEFT", "=", 
   RowBox[{"RGEShadowEFT", "[", 
    RowBox[{"M1", ",", "M2", ",", "M3", ",", 
     SuperscriptBox["10", "17"]}], "]"}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compatibility to the experimental data", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IsCompatibleWithExp", ";"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The following parameters are compatible with the experimental \
data at the 3\[Sigma] CL:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"\<\"\[Theta]12\"\>", ",", "\<\"\[Theta]13\"\>", 
     ",", "\<\"\[Theta]23\"\>", ",", "\<\"\[CapitalDelta]m2atm\"\>", 
     ",", "\<\"\[CapitalDelta]m2sol\"\>"}], "}"}]}],
  SequenceForm[
  "The following parameters are compatible with the experimental data at the \
3\[Sigma] CL:", {
   "\[Theta]12", "\[Theta]13", "\[Theta]23", "\[CapitalDelta]m2atm", 
    "\[CapitalDelta]m2sol"}],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119701901*^9, 3.636847462731737*^9, 
  3.646456138380522*^9, 3.646475887374419*^9}]
}, Open  ]],

Cell["The low energy parameters are", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(12\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=\>\"", ",", 
    RowBox[{"\[Theta]12", "[", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "MZ"}], "]"}], "]"}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(13\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=\>\"", ",", 
    RowBox[{"\[Theta]13", "[", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "MZ"}], "]"}], "]"}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(23\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=\>\"", ",", 
    RowBox[{"\[Theta]23", "[", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "MZ"}], "]"}], "]"}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \(2\)], \(atm\
\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\))=\>\"", ",", 
    RowBox[{"\[CapitalDelta]m2atm", "[", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "MZ"}], "]"}], "]"}], ",", 
    "\"\<\!\(\*SuperscriptBox[\(eV\), \(2\)]\)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \(2\)], \(sol\
\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\))=\>\"", ",", 
    RowBox[{"\[CapitalDelta]m2sol", "[", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "MZ"}], "]"}], "]"}], ",", 
    "\"\<\!\(\*SuperscriptBox[\(eV\), \(2\)]\)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[\(m\), \(1\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=\>\"", ",", 
    RowBox[{"m1", "[", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "MZ"}], "]"}], "]"}], ",", "\"\<eV\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[\(m\), \(2\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=\>\"", ",", 
    RowBox[{"m2", "[", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "MZ"}], "]"}], "]"}], ",", "\"\<eV\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[\(m\), \(3\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=\>\"", ",", 
    RowBox[{"m3", "[", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "MZ"}], "]"}], "]"}], ",", "\"\<eV\>\""}], "]"}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(12\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\))=\"\>", 
   "\[InvisibleSpace]", "32.49476897262566`", 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(\[Theta]\), \(12\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=", 32.49476897262566, "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119716612*^9, 3.636847462760044*^9, 
  3.646456138430859*^9, 3.646475887409971*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(13\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\))=\"\>", 
   "\[InvisibleSpace]", "0.10085307394224913`", 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(\[Theta]\), \(13\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=", 0.10085307394224913`, "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119716612*^9, 3.636847462760044*^9, 
  3.646456138430859*^9, 3.646475887411628*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(23\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\))=\"\>", 
   "\[InvisibleSpace]", "46.96199065442915`", 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(\[Theta]\), \(23\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\))=", 46.96199065442915, "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119716612*^9, 3.636847462760044*^9, 
  3.646456138430859*^9, 3.6464758874130297`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalDelta]m\\), \
\\(2\\)], \\(atm\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\))=\"\>", 
   "\[InvisibleSpace]", "0.0020929958087601472`", 
   "\[InvisibleSpace]", "\<\"\\!\\(\\*SuperscriptBox[\\(eV\\), \
\\(2\\)]\\)\"\>"}],
  SequenceForm[
  "\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \(2\)], \
\(atm\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\))=", 0.0020929958087601472`, 
   "\!\(\*SuperscriptBox[\(eV\), \(2\)]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119716612*^9, 3.636847462760044*^9, 
  3.646456138430859*^9, 3.6464758874148912`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalDelta]m\\), \
\\(2\\)], \\(sol\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\))=\"\>", 
   "\[InvisibleSpace]", "0.00007720436037504617`", 
   "\[InvisibleSpace]", "\<\"\\!\\(\\*SuperscriptBox[\\(eV\\), \
\\(2\\)]\\)\"\>"}],
  SequenceForm[
  "\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \(2\)], \
\(sol\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\))=", 0.00007720436037504617, 
   "\!\(\*SuperscriptBox[\(eV\), \(2\)]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119716612*^9, 3.636847462760044*^9, 
  3.646456138430859*^9, 3.6464758874163513`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(m\\), \
\\(1\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\))=\"\>", 
   "\[InvisibleSpace]", "0.014843437266613078`", 
   "\[InvisibleSpace]", "\<\"eV\"\>"}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(m\), \(1\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\))=", 
   0.014843437266613078`, "eV"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119716612*^9, 3.636847462760044*^9, 
  3.646456138430859*^9, 3.646475887417798*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(m\\), \
\\(2\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\))=\"\>", 
   "\[InvisibleSpace]", "0.017249115637125403`", 
   "\[InvisibleSpace]", "\<\"eV\"\>"}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(m\), \(2\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\))=", 
   0.017249115637125403`, "eV"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119716612*^9, 3.636847462760044*^9, 
  3.646456138430859*^9, 3.6464758874363937`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(m\\), \
\\(3\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\))=\"\>", 
   "\[InvisibleSpace]", "0.04889302403230006`", 
   "\[InvisibleSpace]", "\<\"eV\"\>"}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(m\), \(3\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\))=", 
   0.04889302403230006, "eV"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847119716612*^9, 3.636847462760044*^9, 
  3.646456138430859*^9, 3.646475887438478*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mixing Angles", "Subsection"],

Cell["Draw the plot for the mixing angles", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]12", "[", "t", "]"}], ",", 
       RowBox[{"\[Theta]13", "[", "t", "]"}], ",", 
       RowBox[{"\[Theta]23", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\)(\[Mu]/GeV)\>\"", ",", 
        "\"\<\>\""}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGELogTicksLabeled", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "*", "15"}], ",", 
            RowBox[{
             RowBox[{"ToString", "[", 
              RowBox[{"i", "*", "15"}], "]"}], "<>", "\"\<\[Degree]\>\""}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "*", "15"}], ",", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "ForestGreen", ",", "Blue"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", "ShadowEFT", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubscriptBox["\[Theta]", "12"], ",", 
            RowBox[{"FontColor", "\[Rule]", "Red"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmin", ",", 
            RowBox[{"\[Theta]12", "[", "tmin", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "1.4"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubscriptBox["\[Theta]", "13"], ",", 
            RowBox[{"FontColor", "\[Rule]", "ForestGreen"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmin", ",", 
            RowBox[{"\[Theta]13", "[", "tmin", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubscriptBox["\[Theta]", "23"], ",", 
            RowBox[{"FontColor", "\[Rule]", "Blue"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmin", ",", 
            RowBox[{"\[Theta]23", "[", "tmin", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "1.4"}], "}"}]}], "]"}]}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.435655087000834*^9, 3.435655149172597*^9}, {
   3.435655291841278*^9, 3.435655355632481*^9}, {3.435655474900189*^9, 
   3.43565552545153*^9}, 3.435655622860778*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwd1Hk8VekDx3HrvdcSCuUX2SLiyDW2cs+991upa6kk0liTFppsGdLYskQZ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     "]]}, 
   {RGBColor[0.1, 0.75, 0.2], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV03k4VG0YBnAJMyhU+CpkLds0cypLJZ6HZCotqq+FSpYUpU1ZEsqakBRF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     "]]}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV1ns4VNsbB3A0ZkalcZuOknGbXMbGdnIpYd7k7O1y5FaK0JxQypSOoos7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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0},
  DisplayFunction->Identity,
  Epilog->{
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubscriptBox["\[Theta]", "12"], FontColor -> RGBColor[1, 0, 0], 
        FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[1, 0, 0], FontSize -> 12]& ], 
      TraditionalForm], {1.9596137110710439`, 32.49476897262566}, {-0.8, 
     1.4}], 
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubscriptBox["\[Theta]", "13"], FontColor -> RGBColor[0.1, 0.75, 0.2],
         FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[0.1, 0.75, 0.2], FontSize -> 12]& ],
       TraditionalForm], {1.9596137110710439`, 
     0.10085307394224913`}, {-0.8, -1}], 
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubscriptBox["\[Theta]", "23"], FontColor -> RGBColor[0, 0, 1], 
        FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[0, 0, 1], FontSize -> 12]& ], 
      TraditionalForm], {1.9596137110710439`, 46.96199065442915}, {-0.8, 
     1.4}]},
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(log\\), \\(10\\)]\\)(\[Mu]/GeV)\"", 
      TraditionalForm], None}},
  FrameTicks->{{{{0, 
       FormBox["\"0\[Degree]\"", TraditionalForm]}, {15, 
       FormBox["\"15\[Degree]\"", TraditionalForm]}, {30, 
       FormBox["\"30\[Degree]\"", TraditionalForm]}, {45, 
       FormBox["\"45\[Degree]\"", TraditionalForm]}}, {{0, 
       FormBox["\"\"", TraditionalForm]}, {15, 
       FormBox["\"\"", TraditionalForm]}, {30, 
       FormBox["\"\"", TraditionalForm]}, {45, 
       FormBox["\"\"", TraditionalForm]}}}, {{{2, 
       FormBox["2", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["3", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["4", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["5", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["6", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["7", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["8", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["9", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["10", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["11", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["12", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["13", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["14", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["15", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["16", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["17", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["18", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["19", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox["\"\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{{{
      GrayLevel[0.9], 
      RectangleBox[{10.561453473142157`, -10000}, {
       12.222494362608364`, 10000}]}, {
      GrayLevel[0.8], 
      RectangleBox[{12.222494362608364`, -10000}, {
       14.334981351900138`, 10000}]}, {
      GrayLevel[0.7], 
      RectangleBox[{14.334981351900138`, -10000}, {17, 10000}]}}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6368471205099077`*^9, 3.636847463561467*^9, 
  3.646456139320549*^9, 3.646475888383235*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["RG change of the angles:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[\(\[Theta]\), \(12\)]\) is :    \
\!\(\*SubscriptBox[\(\[Theta]\), \(12\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\
\))-\!\(\*SubscriptBox[\(\[Theta]\), \(12\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\)) = \>\"", ",", 
    RowBox[{
     RowBox[{"\[Theta]12", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"\[Theta]12", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[\(\[Theta]\), \(13\)]\) is :    \
\!\(\*SubscriptBox[\(\[Theta]\), \(13\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\
\))-\!\(\*SubscriptBox[\(\[Theta]\), \(13\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\)) = \>\"", ",", 
    RowBox[{
     RowBox[{"\[Theta]13", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"\[Theta]13", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[\(\[Theta]\), \(23\)]\) is :    \
\!\(\*SubscriptBox[\(\[Theta]\), \(23\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\
\))-\!\(\*SubscriptBox[\(\[Theta]\), \(23\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\)) = \>\"", ",", 
    RowBox[{
     RowBox[{"\[Theta]23", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"\[Theta]23", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(12\\)]\\) is :    \\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(12\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(12\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "5.486653027106939`"}], 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[\(\[Theta]\), \(12\)]\) is :    \
\!\(\*SubscriptBox[\(\[Theta]\), \(12\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\
\))-\!\(\*SubscriptBox[\(\[Theta]\), \(12\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\)) = ", -5.486653027106939, "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847120664076*^9, 3.6368474637158937`*^9, 
  3.646456139612596*^9, 3.646475888647488*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(13\\)]\\) is :    \\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(13\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(13\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.06985689646393398`"}], 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[\(\[Theta]\), \(13\)]\) is :    \
\!\(\*SubscriptBox[\(\[Theta]\), \(13\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\
\))-\!\(\*SubscriptBox[\(\[Theta]\), \(13\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\)) = ", -0.06985689646393398, "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847120664076*^9, 3.6368474637158937`*^9, 
  3.646456139612596*^9, 3.646475888651033*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(23\\)]\\) is :    \\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(23\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \
\\(23\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "1.961979345191473`"}], 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[\(\[Theta]\), \(23\)]\) is :    \
\!\(\*SubscriptBox[\(\[Theta]\), \(23\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\
\))-\!\(\*SubscriptBox[\(\[Theta]\), \(23\)]\)(\!\(\*SubscriptBox[\(M\), \
\(Z\)]\)) = ", -1.961979345191473, "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847120664076*^9, 3.6368474637158937`*^9, 
  3.646456139612596*^9, 3.646475888652379*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Phases", "Subsection"],

Cell["Draw the plot for the phases", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Delta]", "[", "t", "]"}], ",", 
       RowBox[{"\[CurlyPhi]1", "[", "t", "]"}], ",", 
       RowBox[{"\[CurlyPhi]2", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\)(\[Mu]/GeV)\>\"", ",", 
        "\"\<\>\""}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGELogTicksLabeled", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "*", "45"}], ",", 
            RowBox[{
             RowBox[{"ToString", "[", 
              RowBox[{"i", "*", "45"}], "]"}], "<>", "\"\<\[Degree]\>\""}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "8"}], "}"}]}], "]"}], ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "*", "45"}], ",", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "12"}], "}"}]}], "]"}]}], "}"}]}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue", ",", "ForestGreen"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", "ShadowEFT", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{"\[Delta]", ",", 
            RowBox[{"FontColor", "\[Rule]", "Red"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmin", ",", 
            RowBox[{"\[Delta]", "[", "tmin", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "1.4"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubscriptBox["\[CurlyPhi]", "1"], ",", 
            RowBox[{"FontColor", "\[Rule]", "Blue"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmin", ",", 
            RowBox[{"\[CurlyPhi]1", "[", "tmin", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "1.4"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubscriptBox["\[CurlyPhi]", "2"], ",", 
            RowBox[{"FontColor", "\[Rule]", "ForestGreen"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmin", ",", 
            RowBox[{"\[CurlyPhi]2", "[", "tmin", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.435655636439897*^9, 3.435655679288266*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV03k01Psfx3GJmZGftZRUCFH5Yoyd8Gos3zGUiCnrFZWKIlEqRrjKTUmW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     "]]}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwd1Xk01VkcAHBZnofilZQm2ZLt/fBTtgjfkp6hiJQY26k0nEg90cITSfuY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     "]]}, 
   {RGBColor[0.1, 0.75, 0.2], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV1Xs4VPkfB/BDTKRCaFVySyFTphutyvebMBqKZInccsm4RKaoNIgoRSrn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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0},
  DisplayFunction->Identity,
  Epilog->{
    InsetBox[
     FormBox[
      TagBox[
       StyleBox["\[Delta]", FontColor -> RGBColor[1, 0, 0], FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[1, 0, 0], FontSize -> 12]& ], 
      TraditionalForm], {1.9596137110710439`, 18.357868864853835`}, {-0.8, 
     1.4}], 
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubscriptBox["\[CurlyPhi]", "1"], FontColor -> RGBColor[0, 0, 1], 
        FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[0, 0, 1], FontSize -> 12]& ], 
      TraditionalForm], {1.9596137110710439`, 359.93380516770986`}, {-0.8, 
     1.4}], 
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubscriptBox["\[CurlyPhi]", "2"], FontColor -> 
        RGBColor[0.1, 0.75, 0.2], FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[0.1, 0.75, 0.2], FontSize -> 12]& ],
       TraditionalForm], {1.9596137110710439`, 
     0.022875536351643078`}, {-0.8, -1}]},
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(log\\), \\(10\\)]\\)(\[Mu]/GeV)\"", 
      TraditionalForm], None}},
  FrameTicks->{{{{0, 
       FormBox["\"0\[Degree]\"", TraditionalForm]}, {45, 
       FormBox["\"45\[Degree]\"", TraditionalForm]}, {90, 
       FormBox["\"90\[Degree]\"", TraditionalForm]}, {135, 
       FormBox["\"135\[Degree]\"", TraditionalForm]}, {180, 
       FormBox["\"180\[Degree]\"", TraditionalForm]}, {225, 
       FormBox["\"225\[Degree]\"", TraditionalForm]}, {270, 
       FormBox["\"270\[Degree]\"", TraditionalForm]}, {315, 
       FormBox["\"315\[Degree]\"", TraditionalForm]}, {360, 
       FormBox["\"360\[Degree]\"", TraditionalForm]}}, {{0, 
       FormBox["\"\"", TraditionalForm]}, {45, 
       FormBox["\"\"", TraditionalForm]}, {90, 
       FormBox["\"\"", TraditionalForm]}, {135, 
       FormBox["\"\"", TraditionalForm]}, {180, 
       FormBox["\"\"", TraditionalForm]}, {225, 
       FormBox["\"\"", TraditionalForm]}, {270, 
       FormBox["\"\"", TraditionalForm]}, {315, 
       FormBox["\"\"", TraditionalForm]}, {360, 
       FormBox["\"\"", TraditionalForm]}, {405, 
       FormBox["\"\"", TraditionalForm]}, {450, 
       FormBox["\"\"", TraditionalForm]}, {495, 
       FormBox["\"\"", TraditionalForm]}, {540, 
       FormBox["\"\"", TraditionalForm]}}}, {{{2, 
       FormBox["2", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["3", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["4", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["5", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["6", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["7", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["8", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["9", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["10", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["11", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["12", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["13", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["14", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["15", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["16", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["17", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["18", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["19", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox["\"\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{{{
      GrayLevel[0.9], 
      RectangleBox[{10.561453473142157`, -10000}, {
       12.222494362608364`, 10000}]}, {
      GrayLevel[0.8], 
      RectangleBox[{12.222494362608364`, -10000}, {
       14.334981351900138`, 10000}]}, {
      GrayLevel[0.7], 
      RectangleBox[{14.334981351900138`, -10000}, {17, 10000}]}}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.636847121614245*^9, 3.636847464474209*^9, 
  3.646456141643083*^9, 3.646475889931695*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["RG change of the phases:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \[Delta] is:   \[Delta](\!\(\*SubscriptBox[\(M\), \
\(GUT\)]\))-\[Delta](\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = \>\"", ",", " ", 
    RowBox[{
     RowBox[{"\[Delta]", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[\(\[CurlyPhi]\), \(1\)]\) is:   \
\!\(\*SubscriptBox[\(\[CurlyPhi]\), \(1\)]\)(\!\(\*SubscriptBox[\(M\), \
\(GUT\)]\))-\!\(\*SubscriptBox[\(\[CurlyPhi]\), \
\(1\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = \>\"", ",", " ", 
    RowBox[{
     RowBox[{"\[CurlyPhi]1", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"\[CurlyPhi]1", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[\(\[CurlyPhi]\), \(2\)]\) is:   \
\!\(\*SubscriptBox[\(\[CurlyPhi]\), \(2\)]\)(\!\(\*SubscriptBox[\(M\), \
\(GUT\)]\))-\!\(\*SubscriptBox[\(\[CurlyPhi]\), \
\(2\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = \>\"", ",", " ", 
    RowBox[{
     RowBox[{"\[CurlyPhi]2", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"\[CurlyPhi]2", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\<\[Degree]\>\""}], 
   "]"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \[Delta] is:   \
\[Delta](\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\[Delta](\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", "71.60560439938513`", 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "The RG change of \[Delta] is:   \[Delta](\!\(\*SubscriptBox[\(M\), \
\(GUT\)]\))-\[Delta](\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = ", 
   71.60560439938513, "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847122923572*^9, 3.636847464526793*^9, 
  3.646456143029172*^9, 3.646475890002245*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[\\(\[CurlyPhi]\\), \\(1\
\\)]\\) is:   \\!\\(\\*SubscriptBox[\\(\[CurlyPhi]\\), \
\\(1\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[\\(\[CurlyPhi]\\), \
\\(1\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.0199620350896339`"}], 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[\(\[CurlyPhi]\), \(1\)]\) is:   \
\!\(\*SubscriptBox[\(\[CurlyPhi]\), \(1\)]\)(\!\(\*SubscriptBox[\(M\), \
\(GUT\)]\))-\!\(\*SubscriptBox[\(\[CurlyPhi]\), \
\(1\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = ", -0.0199620350896339, 
   "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847122923572*^9, 3.636847464526793*^9, 
  3.646456143029172*^9, 3.646475890008472*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[\\(\[CurlyPhi]\\), \\(2\
\\)]\\) is:   \\!\\(\\*SubscriptBox[\\(\[CurlyPhi]\\), \
\\(2\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[\\(\[CurlyPhi]\\), \
\\(2\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.003958425444707814`"}], 
   "\[InvisibleSpace]", "\<\"\[Degree]\"\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[\(\[CurlyPhi]\), \(2\)]\) is:   \
\!\(\*SubscriptBox[\(\[CurlyPhi]\), \(2\)]\)(\!\(\*SubscriptBox[\(M\), \
\(GUT\)]\))-\!\(\*SubscriptBox[\(\[CurlyPhi]\), \
\(2\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = ", -0.003958425444707814, 
   "\[Degree]"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847122923572*^9, 3.636847464526793*^9, 
  3.646456143029172*^9, 3.646475890009947*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Masses", "Subsection"],

Cell[CellGroupData[{

Cell["mass eigenvalues", "Subsubsection"],

Cell["Draw the plot for the mass eigenvalues", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"tlabel", "=", "4"}], ";"}], "   ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Position", " ", "where", " ", "the", " ", "labels", " ", "m1"}], 
    ",", "m2", ",", 
    RowBox[{"m3", " ", "should", " ", "be", " ", "placed"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"m1", "[", "t", "]"}], ",", 
       RowBox[{"m2", "[", "t", "]"}], ",", 
       RowBox[{"m3", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\)(\[Mu]/GeV)\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(m\), \(i\)]\) [eV]\>\""}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGELogTicksLabeled", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "*", "0.01"}], ",", 
            RowBox[{"PaddedForm", "[", 
             RowBox[{
              RowBox[{"i", "*", "0.01"}], ",", 
              RowBox[{"{", 
               RowBox[{"3", ",", "2"}], "}"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "50"}], "}"}]}], "]"}], ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "*", "0.01"}], ",", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "50"}], "}"}]}], "]"}]}], "}"}]}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue", ",", "ForestGreen"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", "ShadowEFT", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubscriptBox["m", "1"], ",", 
            RowBox[{"FontColor", "\[Rule]", "Red"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tlabel", ",", 
            RowBox[{"m1", "[", "tlabel", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "1.4"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubscriptBox["m", "2"], ",", 
            RowBox[{"FontColor", "\[Rule]", "Blue"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tlabel", ",", 
            RowBox[{"m2", "[", "tlabel", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", 
            RowBox[{"-", "2"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubscriptBox["m", "3"], ",", 
            RowBox[{"FontColor", "\[Rule]", "ForestGreen"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tlabel", ",", 
            RowBox[{"m3", "[", "tlabel", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "1.4"}], "}"}]}], "]"}]}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{3.435655642671777*^9, 3.435655682603495*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV03k4FWscwHHLcRxLIYSyk+0MjmxFeX9E9pTcyppIlC0KJWubuuoY54y0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     "]]}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV0nk0ldsbwHF0HAe3SKauMhc5L14RRTxPLokGkgohiTQochMZy1CGUs57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     "]]}, 
   {RGBColor[0.1, 0.75, 0.2], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV03k0lPsfB3AVM2MdRHdKGVuIB4+bpSSfj6IRXZW0WHPTYk9uK0OkRZGE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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0.012},
  DisplayFunction->Identity,
  Epilog->{
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubscriptBox["m", "1"], FontColor -> RGBColor[1, 0, 0], FontSize -> 
        12], StyleForm[#, FontColor -> RGBColor[1, 0, 0], FontSize -> 12]& ], 
      TraditionalForm], {4, 0.016619332084574844`}, {-0.8, 1.4}], 
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubscriptBox["m", "2"], FontColor -> RGBColor[0, 0, 1], FontSize -> 
        12], StyleForm[#, FontColor -> RGBColor[0, 0, 1], FontSize -> 12]& ], 
      TraditionalForm], {4, 0.01933301215581473}, {-0.8, -2}], 
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubscriptBox["m", "3"], FontColor -> RGBColor[0.1, 0.75, 0.2], 
        FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[0.1, 0.75, 0.2], FontSize -> 12]& ],
       TraditionalForm], {4, 0.05482118382022448}, {-0.8, 1.4}]},
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(i\\)]\\) [eV]\"", TraditionalForm], 
     None}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(log\\), \\(10\\)]\\)(\[Mu]/GeV)\"", 
      TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.00\"", 0., AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.01, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.01\"", 0.01, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.02, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.02\"", 0.02, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.03, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.03\"", 0.03, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.04, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.04\"", 0.04, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.05, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.05\"", 0.05, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.06, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.06\"", 0.06, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.07, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.07\"", 0.07, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.08, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.08\"", 0.08, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.09, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.09\"", 0.09, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.1, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.10\"", 0.1, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.11, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.11\"", 0.11, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.12, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.12\"", 0.12, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.13, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.13\"", 0.13, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.14, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.14\"", 0.14, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.15, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.15\"", 0.15, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.16, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.16\"", 0.16, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.17, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.17\"", 0.17, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.18, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.18\"", 0.18, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.19, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.19\"", 0.19, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.2, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.20\"", 0.2, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.21, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.21\"", 0.21, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.22, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.22\"", 0.22, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.23, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.23\"", 0.23, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.24, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.24\"", 0.24, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.25, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.25\"", 0.25, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.26, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.26\"", 0.26, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.27, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.27\"", 0.27, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.28, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.28\"", 0.28, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.29, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.29\"", 0.29, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.3, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.30\"", 0.3, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.31, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.31\"", 0.31, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.32, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.32\"", 0.32, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.33, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.33\"", 0.33, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.34, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.34\"", 0.34, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.35000000000000003`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 0.35\"", 0.35000000000000003`, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.36, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.36\"", 0.36, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.37, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.37\"", 0.37, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.38, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.38\"", 0.38, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.39, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.39\"", 0.39, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.4, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.40\"", 0.4, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.41000000000000003`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 0.41\"", 0.41000000000000003`, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.42, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.42\"", 0.42, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.43, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.43\"", 0.43, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.44, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.44\"", 0.44, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.45, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.45\"", 0.45, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.46, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.46\"", 0.46, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.47000000000000003`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 0.47\"", 0.47000000000000003`, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.48, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.48\"", 0.48, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.49, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.49\"", 0.49, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}, {0.5, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.50\"", 0.5, AutoDelete -> True], 
         PaddedForm[#, {3, 2}]& ], TraditionalForm]}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {0.01, 
       FormBox["\"\"", TraditionalForm]}, {0.02, 
       FormBox["\"\"", TraditionalForm]}, {0.03, 
       FormBox["\"\"", TraditionalForm]}, {0.04, 
       FormBox["\"\"", TraditionalForm]}, {0.05, 
       FormBox["\"\"", TraditionalForm]}, {0.06, 
       FormBox["\"\"", TraditionalForm]}, {0.07, 
       FormBox["\"\"", TraditionalForm]}, {0.08, 
       FormBox["\"\"", TraditionalForm]}, {0.09, 
       FormBox["\"\"", TraditionalForm]}, {0.1, 
       FormBox["\"\"", TraditionalForm]}, {0.11, 
       FormBox["\"\"", TraditionalForm]}, {0.12, 
       FormBox["\"\"", TraditionalForm]}, {0.13, 
       FormBox["\"\"", TraditionalForm]}, {0.14, 
       FormBox["\"\"", TraditionalForm]}, {0.15, 
       FormBox["\"\"", TraditionalForm]}, {0.16, 
       FormBox["\"\"", TraditionalForm]}, {0.17, 
       FormBox["\"\"", TraditionalForm]}, {0.18, 
       FormBox["\"\"", TraditionalForm]}, {0.19, 
       FormBox["\"\"", TraditionalForm]}, {0.2, 
       FormBox["\"\"", TraditionalForm]}, {0.21, 
       FormBox["\"\"", TraditionalForm]}, {0.22, 
       FormBox["\"\"", TraditionalForm]}, {0.23, 
       FormBox["\"\"", TraditionalForm]}, {0.24, 
       FormBox["\"\"", TraditionalForm]}, {0.25, 
       FormBox["\"\"", TraditionalForm]}, {0.26, 
       FormBox["\"\"", TraditionalForm]}, {0.27, 
       FormBox["\"\"", TraditionalForm]}, {0.28, 
       FormBox["\"\"", TraditionalForm]}, {0.29, 
       FormBox["\"\"", TraditionalForm]}, {0.3, 
       FormBox["\"\"", TraditionalForm]}, {0.31, 
       FormBox["\"\"", TraditionalForm]}, {0.32, 
       FormBox["\"\"", TraditionalForm]}, {0.33, 
       FormBox["\"\"", TraditionalForm]}, {0.34, 
       FormBox["\"\"", TraditionalForm]}, {0.35000000000000003`, 
       FormBox["\"\"", TraditionalForm]}, {0.36, 
       FormBox["\"\"", TraditionalForm]}, {0.37, 
       FormBox["\"\"", TraditionalForm]}, {0.38, 
       FormBox["\"\"", TraditionalForm]}, {0.39, 
       FormBox["\"\"", TraditionalForm]}, {0.4, 
       FormBox["\"\"", TraditionalForm]}, {0.41000000000000003`, 
       FormBox["\"\"", TraditionalForm]}, {0.42, 
       FormBox["\"\"", TraditionalForm]}, {0.43, 
       FormBox["\"\"", TraditionalForm]}, {0.44, 
       FormBox["\"\"", TraditionalForm]}, {0.45, 
       FormBox["\"\"", TraditionalForm]}, {0.46, 
       FormBox["\"\"", TraditionalForm]}, {0.47000000000000003`, 
       FormBox["\"\"", TraditionalForm]}, {0.48, 
       FormBox["\"\"", TraditionalForm]}, {0.49, 
       FormBox["\"\"", TraditionalForm]}, {0.5, 
       FormBox["\"\"", TraditionalForm]}}}, {{{2, 
       FormBox["2", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["3", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["4", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["5", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["6", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["7", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["8", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["9", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["10", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["11", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["12", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["13", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["14", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["15", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["16", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["17", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["18", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["19", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox["\"\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{{{
      GrayLevel[0.9], 
      RectangleBox[{10.561453473142157`, -10000}, {
       12.222494362608364`, 10000}]}, {
      GrayLevel[0.8], 
      RectangleBox[{12.222494362608364`, -10000}, {
       14.334981351900138`, 10000}]}, {
      GrayLevel[0.7], 
      RectangleBox[{14.334981351900138`, -10000}, {17, 10000}]}}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.636847123706056*^9, 3.636847465241275*^9, 
  3.646456145462736*^9, 3.646475890883382*^9}]
}, Open  ]],

Cell["RG change of the masses:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[\(m\), \(1\)]\) is:   \
\!\(\*SubscriptBox[\(m\), \(1\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\))-\!\(\
\*SubscriptBox[\(m\), \(1\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = \>\"", 
    ",", 
    RowBox[{
     RowBox[{"m1", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"m1", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\< eV\>\""}], "]"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[\(m\), \(2\)]\) is:   \
\!\(\*SubscriptBox[\(m\), \(2\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\))-\!\(\
\*SubscriptBox[\(m\), \(2\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = \>\"", 
    ",", 
    RowBox[{
     RowBox[{"m2", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"m2", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\< eV\>\""}], "]"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[\(m\), \(3\)]\) is:   \
\!\(\*SubscriptBox[\(m\), \(3\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\))-\!\(\
\*SubscriptBox[\(m\), \(3\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = \>\"", 
    ",", 
    RowBox[{
     RowBox[{"m3", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"m3", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", "\"\< eV\>\""}], "]"}],
   ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[\\(m\\), \\(1\\)]\\) \
is:   \\!\\(\\*SubscriptBox[\\(m\\), \
\\(1\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[\\(m\\), \
\\(1\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", "0.005156542987093971`", 
   "\[InvisibleSpace]", "\<\" eV\"\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[\(m\), \(1\)]\) is:   \
\!\(\*SubscriptBox[\(m\), \(1\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\))-\!\(\
\*SubscriptBox[\(m\), \(1\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = ", 
   0.005156542987093971, " eV"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847123754135*^9, 3.636847465317541*^9, 
  3.646456145752508*^9, 3.646475891169506*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[\\(m\\), \\(2\\)]\\) \
is:   \\!\\(\\*SubscriptBox[\\(m\\), \
\\(2\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[\\(m\\), \
\\(2\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", "0.006415547841796428`", 
   "\[InvisibleSpace]", "\<\" eV\"\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[\(m\), \(2\)]\) is:   \
\!\(\*SubscriptBox[\(m\), \(2\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\))-\!\(\
\*SubscriptBox[\(m\), \(2\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = ", 
   0.006415547841796428, " eV"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847123754135*^9, 3.636847465317541*^9, 
  3.646456145752508*^9, 3.646475891170878*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[\\(m\\), \\(3\\)]\\) \
is:   \\!\\(\\*SubscriptBox[\\(m\\), \
\\(3\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[\\(m\\), \
\\(3\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", "0.018620175095922176`", 
   "\[InvisibleSpace]", "\<\" eV\"\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[\(m\), \(3\)]\) is:   \
\!\(\*SubscriptBox[\(m\), \(3\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\))-\!\(\
\*SubscriptBox[\(m\), \(3\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = ", 
   0.018620175095922176`, " eV"],
  Editable->False]], "Print",
 CellChangeTimes->{3.636847123754135*^9, 3.636847465317541*^9, 
  3.646456145752508*^9, 3.646475891171855*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["mass squared differences", "Subsubsection"],

Cell["\<\
Draw the plot for the mass squared differences (on a logarithmic scale)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"\[CapitalDelta]m2sol", "[", "t", "]"}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"\[CapitalDelta]m2atm", "[", "t", "]"}], "]"}]}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\)(\[Mu]/GeV)\>\"", ",", 
        "\"\<\!\(\*SubsuperscriptBox[\(\[CapitalDelta]m\), \(i\), \(2\)]\) \
[\!\(\*SuperscriptBox[\(eV\), \(2\)]\)]\>\""}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGELogTicksLabeled", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"RGELogTicksLabeledNegExp", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", 
          RowBox[{"-", "1"}]}], "]"}], ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", 
          RowBox[{"-", "1"}]}], "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"ForestGreen", ",", "Blue"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", "ShadowEFT", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubsuperscriptBox["\[CapitalDelta]m", "sol", "2"], ",", 
            RowBox[{"FontColor", "\[Rule]", "ForestGreen"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmin", ",", 
            RowBox[{"Log", "[", 
             RowBox[{"10", ",", 
              RowBox[{"Abs", "[", 
               RowBox[{"\[CapitalDelta]m2sol", "[", "tmin", "]"}], "]"}]}], 
             "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", 
            RowBox[{"-", "2"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            SubsuperscriptBox["\[CapitalDelta]m", "atm", "2"], ",", 
            RowBox[{"FontColor", "\[Rule]", "Blue"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmin", ",", 
            RowBox[{"Log", "[", 
             RowBox[{"10", ",", 
              RowBox[{"Abs", "[", 
               RowBox[{"\[CapitalDelta]m2atm", "[", "tmin", "]"}], "]"}]}], 
             "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "1.4"}], "}"}]}], "]"}]}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.435655651153079*^9, 3.4361001025721*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.1, 0.75, 0.2], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV1Hk4lekbB3DEOQfTe16hmmSLLMd7OPZC3EkdS5NSQ0eIQoydQQopLSai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     "]]}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV1Hs0ldkbB3C873vOkXJIwrgmobx45VYueUo6dUwpNelIxk8JIZciU5wS
mkrJNbdEKHQRU5IyzU4UGaELoZG7yNFhIlLjt/tjr70+a+/17O/a+1l7iWeg
s5eUhIREHh4/5rfBJRYprnN2pnqPvskFUug076Eg3X/Ozlk45rTvIIUs1esi
Lgnn7BS4vHcVARS6WNdTXZA3Z3dL/mPOr/4U2qGp6FQ+Mmc35yloKvOlkM/g
n6Z+thKQuLatzGMfhfqTdX4+1ygBcdanrgwJKNQ5Nh7xQiQJpfZHDyc7UGhw
+1WzFncSeOYp8ipqFDIPXZT8yZsE/jXOwRhVCsVcjB5fEEzCTo8zU59+otCS
9v+V8KNJKHb6Je6ZCoXc3DX0awpJEAzlPg5XotArnzTVCjEJRe97NvctpBCK
PCOVfZIC1pN6p7fSFOLmTHs8jKNAdwciNmG7I++/2lMoePtBuaeSQ6FZqQ0R
iwsp4K3NVbrEppDFaampCw0UHHDvCPakKHQr6djwyUUs+OPb9fopCQplFgY0
+1xjgYGco9B2mkRfw1z3CW6zoFcybqz8C4kEG3jTm+6zIG3p2hgjbOUBLS2D
5yxY8OC5ptYUiVK1XweKRCxIEAUqUp9JlJBtxQ0xZ0MbX2r0zScSif318j3X
sME+N/PGVmwnm0WW23lsKLqZcaFhjESynSJ3MwEbVi47W/NYRKI45SslUxFs
YB337b79kUSnktlbjtWwYddgd0vSEIkGPT/3+DWyQVZo18zFdljZE+rWygZp
seTEuUESkS0Psm0/sGFI/VDO7wMk2ptbaGI0zgZ9LykDCrs6MKVW4ysb+Jn3
2k/2k0jbLkrAJTjwfVanbyF2lOxB0ZwMBzSr4iSe9pGo+x/XKPEiDrAiz+v/
hg23eIo96hz4J0h/N439n+MS22pjDihWaXcn9ZIo4szrczHbOWAZNeXj0UOi
d7sea4W6ceDUkQsDCtjW+iV3vbw4YA93/J914/t++vu7DUc4QGqlZBphh5PW
tHQWB2q5Zw5/7yLRoeNXGs73csDheqlm9jsSxZcN7oJRDnRWFbbysa/3GQxO
THIgp7U/Y7qTRL28exK7pKVBqKrvsAPbWa7BXJuRhtiRZKP5HSRirnzOuRcp
Dcw8ylHYRqKxat7h98rzYGtTW4bfSxL5sMbUTJxkIPyKl8qBOhKxIpycfZMW
gGvDDdHqeyTyaO4f4xJycCz+xn7zfBI1Fbj0m1jKw9a31cYWiSRKFr92vLxz
ISjpv+JKRpFoINm9a1O8AuxZBovnBeH3LZnotStbBJEFW8499iDR+jibtIgX
ijC/+tXrDc54/a+ksGlCCXKaEtnq9iTS9fv32SMdZZDJZjWEmeP+OeixvmaP
Ctx3VKlaqYf3m0YHySX+BEXtqssrVEikFlQqW3hbFcjUmur0BSSyIkfaIgbV
IEr1mplYgkS3uEYK2RwN4F6oFydOEqgkRPjbt3WaYNi77e6DYQL1OFbzWqy1
4Pytm9opXQRSzHweV9+gBcNup/9Je00guUUCrx7vJeAlmUlaPidQef3okcsz
S8Bswa4KMSLQPo/dvcLT2pBWYxFtfZ9AHdpbe4VLl8L6RjVbi9sE+qrFV9W5
uxQImnzAFOLz+M+HP2zVAWbyTtvoZQK1/LJMrmVEBx7pfRywTSOQ/6XYQPej
yyDUxs86NIFAjbL++2QW68JFty3OMWcI1F7lkrSnUBdOS93ZERBNoDFHDeVX
5npgbCXyehlJoOcsP1OfZj2Ilc7oWhZOoK3fq37P89CHrCilTptDBMrWTA3+
9k0fWirCDtgdJFBqZEjKbPxyIFly4mlfAl2sWsHV0FgBLJceWb39BHLX89X0
qFwBj86TcQGeBGpuvOnD4xvA3O61Y7t+JZB0bhhvy5ABDLa2VgS7Eah15Tbx
vWEDCJwoX+2NXVBrkKE5agDa+/Kq3bDXfOweEYsNwP9IwTAPO8TCMT75qwFU
ZP9yTgO742/NN28X0LBYvkSncTeBrs/Uee41oyHYyjHfGPvIuXyZvy1oCP3X
m62LvV5TeNdsNQ3smKwQNeyu9aYs1hoain/a5C6NvTAhu7iIR4PwaP3ZPlcC
HdUNEYtcaYDLxasysB23qwrDo2g44blmRBqbNdv+sCKahpsnsp9JYlfnpc9M
xdKwOtLkxoyAQFYTiqGhZ2nIgJmYYWz9RDn/kGQaWtq40fXY/auaistSaZg3
rp70GDu3+/yQOI0GL+O9hZXYSozM3sBLNOTapvQXY79sq88tuYzr5ZyYn4cd
f/x0lyiXBj7/qlUmNquJcvW/SoPf5fTis9jVYTVpNwppSOvwHjmJLdSIfjNS
TENXTJDJsR/5nq5VWHGThmsdE2cDsCcDJLb5ltCQnW/tuw27VPGv+KJSGj4R
C382x/b/M/LvoT9ocFgZZqryI//8Wd7+ChqSXn3g9uzC+e9Wxl6tpKHtzhey
FtvNLfxJ/0MaKmxS/yvCfnVjcs1ehM/XjpwLwq7mi8096mmotGKtksQWTpQc
ymmgoVmQsG3ABefLDCjraqQhv/V6YD122fAIveclDd+eJFYmYueeHljq2kmD
kbdhjDZ25NMO+R0iGhKyGj6v30mgVetqRTx5Q+iW0XY4v4NA+VIdxRUKhjDA
TsoPxJZ9Mualt9gQ8u57s52x++yVu1iqhpC/xeH9Yux4B78XtTqGEDDc3JS7
nUADG+Vv268yBPVH+++WOxMoyWlPkN2vhvB5/ND5vq0EGnWbnLC4ZQhD/znG
O20mEP/OCpOGNUbwW1byYOcGnH/E6tnJRiO4P+yg8hoI9H5zy4TAxxjCy6tt
cqwIdH/U36V12hhYM8GknjnuP9L5xO5ZY8heetGJi22rZlnc/d0YPH+Wv/LF
DP8PV09EhkoysIXmutRh73/DbzrOYiCIseYewA4yex+SIseAUnp/aYkpgWIn
2A/+1GGgN0Dxkc1KvF94dIuELgM1Avc3y7A3zhP1rtNjQK5I4V9Z7HnaL2Xq
ljPAZp6u7TEhUMK2S3teGjEQvMmdPoWdWcpIDq1igCidtGhhCHTMJj91uRUD
GV9cyh9gu9UprvC3xvVbTKwKsDW7vzqP2zJQp+zkcgS7gFtbMLuOAW+R/Xt1
7Ngsy9Vr1jPQXhuWyMber3e98YQDAy+GdfnjxgRabndhitrIwMxXyaYa7HkN
knEbNzEw5mqUVYI9uvOwZhyfgc2jHQHp2I29g3caHfH9+HJ4J7FLDgo2ym1m
IP1cha4/9v8Bdi59xA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{2., -4.2},
  DisplayFunction->Identity,
  Epilog->{
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubsuperscriptBox["\[CapitalDelta]m", "sol", "2"], FontColor -> 
        RGBColor[0.1, 0.75, 0.2], FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[0.1, 0.75, 0.2], FontSize -> 12]& ],
       TraditionalForm], {
     1.9596137110710439`, -4.1123581707349315`}, {-0.8, -2}], 
    InsetBox[
     FormBox[
      TagBox[
       StyleBox[
        SubsuperscriptBox["\[CapitalDelta]m", "atm", "2"], FontColor -> 
        RGBColor[0, 0, 1], FontSize -> 12], 
       StyleForm[#, FontColor -> RGBColor[0, 0, 1], FontSize -> 12]& ], 
      TraditionalForm], {1.9596137110710439`, -2.6792316413384096`}, {-0.8, 
     1.4}]},
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*SubsuperscriptBox[\\(\[CapitalDelta]m\\), \\(i\\), \
\\(2\\)]\\) [\\!\\(\\*SuperscriptBox[\\(eV\\), \\(2\\)]\\)]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(log\\), \\(10\\)]\\)(\[Mu]/GeV)\"", 
      TraditionalForm], None}},
  FrameTicks->{{{{-6, 
       FormBox["\"\\!\\(10\\^\\(-6\\)\\)\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[500000], -5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000000, 3]], -5.5228787452803365`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[250000], -5.397940008672037], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[200000], -5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[500000, 3]], -5.221848749616355], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000000, 7]], -5.154901959985742], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[125000], -5.096910013008055], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000000, 9]], -5.045757490560675], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-5, 
       FormBox["\"\\!\\(10\\^\\(-5\\)\\)\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[50000], -4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100000, 3]], -4.522878745280337], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[25000], -4.397940008672037], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[20000], -4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[50000, 3]], -4.221848749616356], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100000, 7]], -4.154901959985742], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[12500], -4.096910013008055], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100000, 9]], -4.045757490560674], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-4, 
       FormBox["\"\\!\\(10\\^\\(-4\\)\\)\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[5000], -3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[10000, 3]], -3.522878745280337], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[2500], -3.397940008672037], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[2000], -3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[5000, 3]], -3.221848749616356], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[10000, 7]], -3.1549019599857426`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[1250], -3.096910013008056], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[10000, 9]], -3.045757490560675], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-3, 
       FormBox["\"\\!\\(10\\^\\(-3\\)\\)\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[500], -2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000, 3]], -2.5228787452803374`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[250], -2.397940008672037], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[200], -2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[500, 3]], -2.221848749616356], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000, 7]], -2.1549019599857426`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[125], -2.0969100130080562`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000, 9]], -2.045757490560675], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-2, 
       FormBox["\"\\!\\(10\\^\\(-2\\)\\)\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[50], -1.6989700043360185`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100, 3]], -1.5228787452803374`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[25], -1.3979400086720373`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[20], -1.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[50, 3]], -1.2218487496163561`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100, 7]], -1.1549019599857429`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[25, 2]], -1.0969100130080562`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100, 9]], -1.0457574905606748`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-1, 
       FormBox["\"\\!\\(10\\^\\(-1\\)\\)\"", TraditionalForm]}, {
       NCache[-Log[5]/Log[10], -0.6989700043360186], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[10, 3]]/Log[10], -0.5228787452803375], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[5, 2]]/Log[10], -0.39794000867203755`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[2]/Log[10], -0.30102999566398114`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[5, 3]]/Log[10], -0.22184874961635634`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[10, 7]]/Log[10], -0.15490195998574316`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[5, 4]]/Log[10], -0.0969100130080564], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[10, 9]]/Log[10], -0.04575749056067514], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{-6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[500000], -5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000000, 3]], -5.5228787452803365`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[250000], -5.397940008672037], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[200000], -5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[500000, 3]], -5.221848749616355], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000000, 7]], -5.154901959985742], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[125000], -5.096910013008055], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000000, 9]], -5.045757490560675], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[50000], -4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100000, 3]], -4.522878745280337], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[25000], -4.397940008672037], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[20000], -4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[50000, 3]], -4.221848749616356], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100000, 7]], -4.154901959985742], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[12500], -4.096910013008055], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100000, 9]], -4.045757490560674], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[5000], -3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[10000, 3]], -3.522878745280337], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[2500], -3.397940008672037], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[2000], -3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[5000, 3]], -3.221848749616356], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[10000, 7]], -3.1549019599857426`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[1250], -3.096910013008056], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[10000, 9]], -3.045757490560675], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[500], -2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000, 3]], -2.5228787452803374`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[250], -2.397940008672037], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[200], -2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[500, 3]], -2.221848749616356], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000, 7]], -2.1549019599857426`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[125], -2.0969100130080562`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[1000, 9]], -2.045757490560675], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[-Log[10]^(-1) Log[50], -1.6989700043360185`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100, 3]], -1.5228787452803374`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[25], -1.3979400086720373`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[20], -1.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[50, 3]], -1.2218487496163561`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100, 7]], -1.1549019599857429`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[25, 2]], -1.0969100130080562`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[10]^(-1) Log[
          Rational[100, 9]], -1.0457574905606748`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {-1, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[-Log[5]/Log[10], -0.6989700043360186], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[10, 3]]/Log[10], -0.5228787452803375], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[5, 2]]/Log[10], -0.39794000867203755`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[2]/Log[10], -0.30102999566398114`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[5, 3]]/Log[10], -0.22184874961635634`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[10, 7]]/Log[10], -0.15490195998574316`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[5, 4]]/Log[10], -0.0969100130080564], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[-Log[
          Rational[10, 9]]/Log[10], -0.04575749056067514], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}, {{{2, 
       FormBox["2", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["3", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["4", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["5", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["6", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["7", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["8", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["9", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["10", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["11", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["12", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["13", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["14", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["15", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["16", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["17", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["18", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["19", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox["\"\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{{{
      GrayLevel[0.9], 
      RectangleBox[{10.561453473142157`, -10000}, {
       12.222494362608364`, 10000}]}, {
      GrayLevel[0.8], 
      RectangleBox[{12.222494362608364`, -10000}, {
       14.334981351900138`, 10000}]}, {
      GrayLevel[0.7], 
      RectangleBox[{14.334981351900138`, -10000}, {17, 10000}]}}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.636847124652256*^9, 3.6368474661977262`*^9, 
  3.646456146963194*^9, 3.6464758921807203`*^9}]
}, Open  ]],

Cell["\<\
Draw the plot for the solar mass squared difference (on a linear scale)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]m2sol", "[", "t", "]"}], "*", 
      RowBox[{"10", "^", "5"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\)(\[Mu]/GeV)\>\"", ",", 
        "\"\<\!\(\*SubsuperscriptBox[\(\[CapitalDelta]m\), \(sol\), \(2\)]\) \
[\!\(\*SuperscriptBox[\(10\), \
\(-5\)]\)\[ThinSpace]\!\(\*SuperscriptBox[\(eV\), \(2\)]\)]\>\""}], "}"}]}], 
     ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGELogTicksLabeled", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i", ",", "i"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "100"}], ",", "100"}], "}"}]}], "]"}], ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i", ",", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "100"}], ",", "100"}], "}"}]}], "]"}]}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "ForestGreen", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", "ShadowEFT", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.435655655075964*^9, 3.435655686756006*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.1, 0.75, 0.2], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwVknk4lekbxwnHkSlkybQ4zutYz/uecxpLInyTHEMSpTqSaUg0lDqTqJCo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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{2., 7.5},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*SubsuperscriptBox[\\(\[CapitalDelta]m\\), \\(sol\\), \
\\(2\\)]\\) [\\!\\(\\*SuperscriptBox[\\(10\\), \\(-5\\)]\\)\[ThinSpace]\\!\\(\
\\*SuperscriptBox[\\(eV\\), \\(2\\)]\\)]\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(log\\), \\(10\\)]\\)(\[Mu]/GeV)\"", 
      TraditionalForm], None}},
  FrameTicks->{{{{-100, 
       FormBox[
        RowBox[{"-", "100"}], TraditionalForm]}, {-99, 
       FormBox[
        RowBox[{"-", "99"}], TraditionalForm]}, {-98, 
       FormBox[
        RowBox[{"-", "98"}], TraditionalForm]}, {-97, 
       FormBox[
        RowBox[{"-", "97"}], TraditionalForm]}, {-96, 
       FormBox[
        RowBox[{"-", "96"}], TraditionalForm]}, {-95, 
       FormBox[
        RowBox[{"-", "95"}], TraditionalForm]}, {-94, 
       FormBox[
        RowBox[{"-", "94"}], TraditionalForm]}, {-93, 
       FormBox[
        RowBox[{"-", "93"}], TraditionalForm]}, {-92, 
       FormBox[
        RowBox[{"-", "92"}], TraditionalForm]}, {-91, 
       FormBox[
        RowBox[{"-", "91"}], TraditionalForm]}, {-90, 
       FormBox[
        RowBox[{"-", "90"}], TraditionalForm]}, {-89, 
       FormBox[
        RowBox[{"-", "89"}], TraditionalForm]}, {-88, 
       FormBox[
        RowBox[{"-", "88"}], TraditionalForm]}, {-87, 
       FormBox[
        RowBox[{"-", "87"}], TraditionalForm]}, {-86, 
       FormBox[
        RowBox[{"-", "86"}], TraditionalForm]}, {-85, 
       FormBox[
        RowBox[{"-", "85"}], TraditionalForm]}, {-84, 
       FormBox[
        RowBox[{"-", "84"}], TraditionalForm]}, {-83, 
       FormBox[
        RowBox[{"-", "83"}], TraditionalForm]}, {-82, 
       FormBox[
        RowBox[{"-", "82"}], TraditionalForm]}, {-81, 
       FormBox[
        RowBox[{"-", "81"}], TraditionalForm]}, {-80, 
       FormBox[
        RowBox[{"-", "80"}], TraditionalForm]}, {-79, 
       FormBox[
        RowBox[{"-", "79"}], TraditionalForm]}, {-78, 
       FormBox[
        RowBox[{"-", "78"}], TraditionalForm]}, {-77, 
       FormBox[
        RowBox[{"-", "77"}], TraditionalForm]}, {-76, 
       FormBox[
        RowBox[{"-", "76"}], TraditionalForm]}, {-75, 
       FormBox[
        RowBox[{"-", "75"}], TraditionalForm]}, {-74, 
       FormBox[
        RowBox[{"-", "74"}], TraditionalForm]}, {-73, 
       FormBox[
        RowBox[{"-", "73"}], TraditionalForm]}, {-72, 
       FormBox[
        RowBox[{"-", "72"}], TraditionalForm]}, {-71, 
       FormBox[
        RowBox[{"-", "71"}], TraditionalForm]}, {-70, 
       FormBox[
        RowBox[{"-", "70"}], TraditionalForm]}, {-69, 
       FormBox[
        RowBox[{"-", "69"}], TraditionalForm]}, {-68, 
       FormBox[
        RowBox[{"-", "68"}], TraditionalForm]}, {-67, 
       FormBox[
        RowBox[{"-", "67"}], TraditionalForm]}, {-66, 
       FormBox[
        RowBox[{"-", "66"}], TraditionalForm]}, {-65, 
       FormBox[
        RowBox[{"-", "65"}], TraditionalForm]}, {-64, 
       FormBox[
        RowBox[{"-", "64"}], TraditionalForm]}, {-63, 
       FormBox[
        RowBox[{"-", "63"}], TraditionalForm]}, {-62, 
       FormBox[
        RowBox[{"-", "62"}], TraditionalForm]}, {-61, 
       FormBox[
        RowBox[{"-", "61"}], TraditionalForm]}, {-60, 
       FormBox[
        RowBox[{"-", "60"}], TraditionalForm]}, {-59, 
       FormBox[
        RowBox[{"-", "59"}], TraditionalForm]}, {-58, 
       FormBox[
        RowBox[{"-", "58"}], TraditionalForm]}, {-57, 
       FormBox[
        RowBox[{"-", "57"}], TraditionalForm]}, {-56, 
       FormBox[
        RowBox[{"-", "56"}], TraditionalForm]}, {-55, 
       FormBox[
        RowBox[{"-", "55"}], TraditionalForm]}, {-54, 
       FormBox[
        RowBox[{"-", "54"}], TraditionalForm]}, {-53, 
       FormBox[
        RowBox[{"-", "53"}], TraditionalForm]}, {-52, 
       FormBox[
        RowBox[{"-", "52"}], TraditionalForm]}, {-51, 
       FormBox[
        RowBox[{"-", "51"}], TraditionalForm]}, {-50, 
       FormBox[
        RowBox[{"-", "50"}], TraditionalForm]}, {-49, 
       FormBox[
        RowBox[{"-", "49"}], TraditionalForm]}, {-48, 
       FormBox[
        RowBox[{"-", "48"}], TraditionalForm]}, {-47, 
       FormBox[
        RowBox[{"-", "47"}], TraditionalForm]}, {-46, 
       FormBox[
        RowBox[{"-", "46"}], TraditionalForm]}, {-45, 
       FormBox[
        RowBox[{"-", "45"}], TraditionalForm]}, {-44, 
       FormBox[
        RowBox[{"-", "44"}], TraditionalForm]}, {-43, 
       FormBox[
        RowBox[{"-", "43"}], TraditionalForm]}, {-42, 
       FormBox[
        RowBox[{"-", "42"}], TraditionalForm]}, {-41, 
       FormBox[
        RowBox[{"-", "41"}], TraditionalForm]}, {-40, 
       FormBox[
        RowBox[{"-", "40"}], TraditionalForm]}, {-39, 
       FormBox[
        RowBox[{"-", "39"}], TraditionalForm]}, {-38, 
       FormBox[
        RowBox[{"-", "38"}], TraditionalForm]}, {-37, 
       FormBox[
        RowBox[{"-", "37"}], TraditionalForm]}, {-36, 
       FormBox[
        RowBox[{"-", "36"}], TraditionalForm]}, {-35, 
       FormBox[
        RowBox[{"-", "35"}], TraditionalForm]}, {-34, 
       FormBox[
        RowBox[{"-", "34"}], TraditionalForm]}, {-33, 
       FormBox[
        RowBox[{"-", "33"}], TraditionalForm]}, {-32, 
       FormBox[
        RowBox[{"-", "32"}], TraditionalForm]}, {-31, 
       FormBox[
        RowBox[{"-", "31"}], TraditionalForm]}, {-30, 
       FormBox[
        RowBox[{"-", "30"}], TraditionalForm]}, {-29, 
       FormBox[
        RowBox[{"-", "29"}], TraditionalForm]}, {-28, 
       FormBox[
        RowBox[{"-", "28"}], TraditionalForm]}, {-27, 
       FormBox[
        RowBox[{"-", "27"}], TraditionalForm]}, {-26, 
       FormBox[
        RowBox[{"-", "26"}], TraditionalForm]}, {-25, 
       FormBox[
        RowBox[{"-", "25"}], TraditionalForm]}, {-24, 
       FormBox[
        RowBox[{"-", "24"}], TraditionalForm]}, {-23, 
       FormBox[
        RowBox[{"-", "23"}], TraditionalForm]}, {-22, 
       FormBox[
        RowBox[{"-", "22"}], TraditionalForm]}, {-21, 
       FormBox[
        RowBox[{"-", "21"}], TraditionalForm]}, {-20, 
       FormBox[
        RowBox[{"-", "20"}], TraditionalForm]}, {-19, 
       FormBox[
        RowBox[{"-", "19"}], TraditionalForm]}, {-18, 
       FormBox[
        RowBox[{"-", "18"}], TraditionalForm]}, {-17, 
       FormBox[
        RowBox[{"-", "17"}], TraditionalForm]}, {-16, 
       FormBox[
        RowBox[{"-", "16"}], TraditionalForm]}, {-15, 
       FormBox[
        RowBox[{"-", "15"}], TraditionalForm]}, {-14, 
       FormBox[
        RowBox[{"-", "14"}], TraditionalForm]}, {-13, 
       FormBox[
        RowBox[{"-", "13"}], TraditionalForm]}, {-12, 
       FormBox[
        RowBox[{"-", "12"}], TraditionalForm]}, {-11, 
       FormBox[
        RowBox[{"-", "11"}], TraditionalForm]}, {-10, 
       FormBox[
        RowBox[{"-", "10"}], TraditionalForm]}, {-9, 
       FormBox[
        RowBox[{"-", "9"}], TraditionalForm]}, {-8, 
       FormBox[
        RowBox[{"-", "8"}], TraditionalForm]}, {-7, 
       FormBox[
        RowBox[{"-", "7"}], TraditionalForm]}, {-6, 
       FormBox[
        RowBox[{"-", "6"}], TraditionalForm]}, {-5, 
       FormBox[
        RowBox[{"-", "5"}], TraditionalForm]}, {-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-3, 
       FormBox[
        RowBox[{"-", "3"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {-1, 
       FormBox[
        RowBox[{"-", "1"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}, {5, 
       FormBox["5", TraditionalForm]}, {6, 
       FormBox["6", TraditionalForm]}, {7, 
       FormBox["7", TraditionalForm]}, {8, 
       FormBox["8", TraditionalForm]}, {9, 
       FormBox["9", TraditionalForm]}, {10, 
       FormBox["10", TraditionalForm]}, {11, 
       FormBox["11", TraditionalForm]}, {12, 
       FormBox["12", TraditionalForm]}, {13, 
       FormBox["13", TraditionalForm]}, {14, 
       FormBox["14", TraditionalForm]}, {15, 
       FormBox["15", TraditionalForm]}, {16, 
       FormBox["16", TraditionalForm]}, {17, 
       FormBox["17", TraditionalForm]}, {18, 
       FormBox["18", TraditionalForm]}, {19, 
       FormBox["19", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {21, 
       FormBox["21", TraditionalForm]}, {22, 
       FormBox["22", TraditionalForm]}, {23, 
       FormBox["23", TraditionalForm]}, {24, 
       FormBox["24", TraditionalForm]}, {25, 
       FormBox["25", TraditionalForm]}, {26, 
       FormBox["26", TraditionalForm]}, {27, 
       FormBox["27", TraditionalForm]}, {28, 
       FormBox["28", TraditionalForm]}, {29, 
       FormBox["29", TraditionalForm]}, {30, 
       FormBox["30", TraditionalForm]}, {31, 
       FormBox["31", TraditionalForm]}, {32, 
       FormBox["32", TraditionalForm]}, {33, 
       FormBox["33", TraditionalForm]}, {34, 
       FormBox["34", TraditionalForm]}, {35, 
       FormBox["35", TraditionalForm]}, {36, 
       FormBox["36", TraditionalForm]}, {37, 
       FormBox["37", TraditionalForm]}, {38, 
       FormBox["38", TraditionalForm]}, {39, 
       FormBox["39", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {41, 
       FormBox["41", TraditionalForm]}, {42, 
       FormBox["42", TraditionalForm]}, {43, 
       FormBox["43", TraditionalForm]}, {44, 
       FormBox["44", TraditionalForm]}, {45, 
       FormBox["45", TraditionalForm]}, {46, 
       FormBox["46", TraditionalForm]}, {47, 
       FormBox["47", TraditionalForm]}, {48, 
       FormBox["48", TraditionalForm]}, {49, 
       FormBox["49", TraditionalForm]}, {50, 
       FormBox["50", TraditionalForm]}, {51, 
       FormBox["51", TraditionalForm]}, {52, 
       FormBox["52", TraditionalForm]}, {53, 
       FormBox["53", TraditionalForm]}, {54, 
       FormBox["54", TraditionalForm]}, {55, 
       FormBox["55", TraditionalForm]}, {56, 
       FormBox["56", TraditionalForm]}, {57, 
       FormBox["57", TraditionalForm]}, {58, 
       FormBox["58", TraditionalForm]}, {59, 
       FormBox["59", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {61, 
       FormBox["61", TraditionalForm]}, {62, 
       FormBox["62", TraditionalForm]}, {63, 
       FormBox["63", TraditionalForm]}, {64, 
       FormBox["64", TraditionalForm]}, {65, 
       FormBox["65", TraditionalForm]}, {66, 
       FormBox["66", TraditionalForm]}, {67, 
       FormBox["67", TraditionalForm]}, {68, 
       FormBox["68", TraditionalForm]}, {69, 
       FormBox["69", TraditionalForm]}, {70, 
       FormBox["70", TraditionalForm]}, {71, 
       FormBox["71", TraditionalForm]}, {72, 
       FormBox["72", TraditionalForm]}, {73, 
       FormBox["73", TraditionalForm]}, {74, 
       FormBox["74", TraditionalForm]}, {75, 
       FormBox["75", TraditionalForm]}, {76, 
       FormBox["76", TraditionalForm]}, {77, 
       FormBox["77", TraditionalForm]}, {78, 
       FormBox["78", TraditionalForm]}, {79, 
       FormBox["79", TraditionalForm]}, {80, 
       FormBox["80", TraditionalForm]}, {81, 
       FormBox["81", TraditionalForm]}, {82, 
       FormBox["82", TraditionalForm]}, {83, 
       FormBox["83", TraditionalForm]}, {84, 
       FormBox["84", TraditionalForm]}, {85, 
       FormBox["85", TraditionalForm]}, {86, 
       FormBox["86", TraditionalForm]}, {87, 
       FormBox["87", TraditionalForm]}, {88, 
       FormBox["88", TraditionalForm]}, {89, 
       FormBox["89", TraditionalForm]}, {90, 
       FormBox["90", TraditionalForm]}, {91, 
       FormBox["91", TraditionalForm]}, {92, 
       FormBox["92", TraditionalForm]}, {93, 
       FormBox["93", TraditionalForm]}, {94, 
       FormBox["94", TraditionalForm]}, {95, 
       FormBox["95", TraditionalForm]}, {96, 
       FormBox["96", TraditionalForm]}, {97, 
       FormBox["97", TraditionalForm]}, {98, 
       FormBox["98", TraditionalForm]}, {99, 
       FormBox["99", TraditionalForm]}, {100, 
       FormBox["100", TraditionalForm]}}, {{-100, 
       FormBox["\"\"", TraditionalForm]}, {-99, 
       FormBox["\"\"", TraditionalForm]}, {-98, 
       FormBox["\"\"", TraditionalForm]}, {-97, 
       FormBox["\"\"", TraditionalForm]}, {-96, 
       FormBox["\"\"", TraditionalForm]}, {-95, 
       FormBox["\"\"", TraditionalForm]}, {-94, 
       FormBox["\"\"", TraditionalForm]}, {-93, 
       FormBox["\"\"", TraditionalForm]}, {-92, 
       FormBox["\"\"", TraditionalForm]}, {-91, 
       FormBox["\"\"", TraditionalForm]}, {-90, 
       FormBox["\"\"", TraditionalForm]}, {-89, 
       FormBox["\"\"", TraditionalForm]}, {-88, 
       FormBox["\"\"", TraditionalForm]}, {-87, 
       FormBox["\"\"", TraditionalForm]}, {-86, 
       FormBox["\"\"", TraditionalForm]}, {-85, 
       FormBox["\"\"", TraditionalForm]}, {-84, 
       FormBox["\"\"", TraditionalForm]}, {-83, 
       FormBox["\"\"", TraditionalForm]}, {-82, 
       FormBox["\"\"", TraditionalForm]}, {-81, 
       FormBox["\"\"", TraditionalForm]}, {-80, 
       FormBox["\"\"", TraditionalForm]}, {-79, 
       FormBox["\"\"", TraditionalForm]}, {-78, 
       FormBox["\"\"", TraditionalForm]}, {-77, 
       FormBox["\"\"", TraditionalForm]}, {-76, 
       FormBox["\"\"", TraditionalForm]}, {-75, 
       FormBox["\"\"", TraditionalForm]}, {-74, 
       FormBox["\"\"", TraditionalForm]}, {-73, 
       FormBox["\"\"", TraditionalForm]}, {-72, 
       FormBox["\"\"", TraditionalForm]}, {-71, 
       FormBox["\"\"", TraditionalForm]}, {-70, 
       FormBox["\"\"", TraditionalForm]}, {-69, 
       FormBox["\"\"", TraditionalForm]}, {-68, 
       FormBox["\"\"", TraditionalForm]}, {-67, 
       FormBox["\"\"", TraditionalForm]}, {-66, 
       FormBox["\"\"", TraditionalForm]}, {-65, 
       FormBox["\"\"", TraditionalForm]}, {-64, 
       FormBox["\"\"", TraditionalForm]}, {-63, 
       FormBox["\"\"", TraditionalForm]}, {-62, 
       FormBox["\"\"", TraditionalForm]}, {-61, 
       FormBox["\"\"", TraditionalForm]}, {-60, 
       FormBox["\"\"", TraditionalForm]}, {-59, 
       FormBox["\"\"", TraditionalForm]}, {-58, 
       FormBox["\"\"", TraditionalForm]}, {-57, 
       FormBox["\"\"", TraditionalForm]}, {-56, 
       FormBox["\"\"", TraditionalForm]}, {-55, 
       FormBox["\"\"", TraditionalForm]}, {-54, 
       FormBox["\"\"", TraditionalForm]}, {-53, 
       FormBox["\"\"", TraditionalForm]}, {-52, 
       FormBox["\"\"", TraditionalForm]}, {-51, 
       FormBox["\"\"", TraditionalForm]}, {-50, 
       FormBox["\"\"", TraditionalForm]}, {-49, 
       FormBox["\"\"", TraditionalForm]}, {-48, 
       FormBox["\"\"", TraditionalForm]}, {-47, 
       FormBox["\"\"", TraditionalForm]}, {-46, 
       FormBox["\"\"", TraditionalForm]}, {-45, 
       FormBox["\"\"", TraditionalForm]}, {-44, 
       FormBox["\"\"", TraditionalForm]}, {-43, 
       FormBox["\"\"", TraditionalForm]}, {-42, 
       FormBox["\"\"", TraditionalForm]}, {-41, 
       FormBox["\"\"", TraditionalForm]}, {-40, 
       FormBox["\"\"", TraditionalForm]}, {-39, 
       FormBox["\"\"", TraditionalForm]}, {-38, 
       FormBox["\"\"", TraditionalForm]}, {-37, 
       FormBox["\"\"", TraditionalForm]}, {-36, 
       FormBox["\"\"", TraditionalForm]}, {-35, 
       FormBox["\"\"", TraditionalForm]}, {-34, 
       FormBox["\"\"", TraditionalForm]}, {-33, 
       FormBox["\"\"", TraditionalForm]}, {-32, 
       FormBox["\"\"", TraditionalForm]}, {-31, 
       FormBox["\"\"", TraditionalForm]}, {-30, 
       FormBox["\"\"", TraditionalForm]}, {-29, 
       FormBox["\"\"", TraditionalForm]}, {-28, 
       FormBox["\"\"", TraditionalForm]}, {-27, 
       FormBox["\"\"", TraditionalForm]}, {-26, 
       FormBox["\"\"", TraditionalForm]}, {-25, 
       FormBox["\"\"", TraditionalForm]}, {-24, 
       FormBox["\"\"", TraditionalForm]}, {-23, 
       FormBox["\"\"", TraditionalForm]}, {-22, 
       FormBox["\"\"", TraditionalForm]}, {-21, 
       FormBox["\"\"", TraditionalForm]}, {-20, 
       FormBox["\"\"", TraditionalForm]}, {-19, 
       FormBox["\"\"", TraditionalForm]}, {-18, 
       FormBox["\"\"", TraditionalForm]}, {-17, 
       FormBox["\"\"", TraditionalForm]}, {-16, 
       FormBox["\"\"", TraditionalForm]}, {-15, 
       FormBox["\"\"", TraditionalForm]}, {-14, 
       FormBox["\"\"", TraditionalForm]}, {-13, 
       FormBox["\"\"", TraditionalForm]}, {-12, 
       FormBox["\"\"", TraditionalForm]}, {-11, 
       FormBox["\"\"", TraditionalForm]}, {-10, 
       FormBox["\"\"", TraditionalForm]}, {-9, 
       FormBox["\"\"", TraditionalForm]}, {-8, 
       FormBox["\"\"", TraditionalForm]}, {-7, 
       FormBox["\"\"", TraditionalForm]}, {-6, 
       FormBox["\"\"", TraditionalForm]}, {-5, 
       FormBox["\"\"", TraditionalForm]}, {-4, 
       FormBox["\"\"", TraditionalForm]}, {-3, 
       FormBox["\"\"", TraditionalForm]}, {-2, 
       FormBox["\"\"", TraditionalForm]}, {-1, 
       FormBox["\"\"", TraditionalForm]}, {0, 
       FormBox["\"\"", TraditionalForm]}, {1, 
       FormBox["\"\"", TraditionalForm]}, {2, 
       FormBox["\"\"", TraditionalForm]}, {3, 
       FormBox["\"\"", TraditionalForm]}, {4, 
       FormBox["\"\"", TraditionalForm]}, {5, 
       FormBox["\"\"", TraditionalForm]}, {6, 
       FormBox["\"\"", TraditionalForm]}, {7, 
       FormBox["\"\"", TraditionalForm]}, {8, 
       FormBox["\"\"", TraditionalForm]}, {9, 
       FormBox["\"\"", TraditionalForm]}, {10, 
       FormBox["\"\"", TraditionalForm]}, {11, 
       FormBox["\"\"", TraditionalForm]}, {12, 
       FormBox["\"\"", TraditionalForm]}, {13, 
       FormBox["\"\"", TraditionalForm]}, {14, 
       FormBox["\"\"", TraditionalForm]}, {15, 
       FormBox["\"\"", TraditionalForm]}, {16, 
       FormBox["\"\"", TraditionalForm]}, {17, 
       FormBox["\"\"", TraditionalForm]}, {18, 
       FormBox["\"\"", TraditionalForm]}, {19, 
       FormBox["\"\"", TraditionalForm]}, {20, 
       FormBox["\"\"", TraditionalForm]}, {21, 
       FormBox["\"\"", TraditionalForm]}, {22, 
       FormBox["\"\"", TraditionalForm]}, {23, 
       FormBox["\"\"", TraditionalForm]}, {24, 
       FormBox["\"\"", TraditionalForm]}, {25, 
       FormBox["\"\"", TraditionalForm]}, {26, 
       FormBox["\"\"", TraditionalForm]}, {27, 
       FormBox["\"\"", TraditionalForm]}, {28, 
       FormBox["\"\"", TraditionalForm]}, {29, 
       FormBox["\"\"", TraditionalForm]}, {30, 
       FormBox["\"\"", TraditionalForm]}, {31, 
       FormBox["\"\"", TraditionalForm]}, {32, 
       FormBox["\"\"", TraditionalForm]}, {33, 
       FormBox["\"\"", TraditionalForm]}, {34, 
       FormBox["\"\"", TraditionalForm]}, {35, 
       FormBox["\"\"", TraditionalForm]}, {36, 
       FormBox["\"\"", TraditionalForm]}, {37, 
       FormBox["\"\"", TraditionalForm]}, {38, 
       FormBox["\"\"", TraditionalForm]}, {39, 
       FormBox["\"\"", TraditionalForm]}, {40, 
       FormBox["\"\"", TraditionalForm]}, {41, 
       FormBox["\"\"", TraditionalForm]}, {42, 
       FormBox["\"\"", TraditionalForm]}, {43, 
       FormBox["\"\"", TraditionalForm]}, {44, 
       FormBox["\"\"", TraditionalForm]}, {45, 
       FormBox["\"\"", TraditionalForm]}, {46, 
       FormBox["\"\"", TraditionalForm]}, {47, 
       FormBox["\"\"", TraditionalForm]}, {48, 
       FormBox["\"\"", TraditionalForm]}, {49, 
       FormBox["\"\"", TraditionalForm]}, {50, 
       FormBox["\"\"", TraditionalForm]}, {51, 
       FormBox["\"\"", TraditionalForm]}, {52, 
       FormBox["\"\"", TraditionalForm]}, {53, 
       FormBox["\"\"", TraditionalForm]}, {54, 
       FormBox["\"\"", TraditionalForm]}, {55, 
       FormBox["\"\"", TraditionalForm]}, {56, 
       FormBox["\"\"", TraditionalForm]}, {57, 
       FormBox["\"\"", TraditionalForm]}, {58, 
       FormBox["\"\"", TraditionalForm]}, {59, 
       FormBox["\"\"", TraditionalForm]}, {60, 
       FormBox["\"\"", TraditionalForm]}, {61, 
       FormBox["\"\"", TraditionalForm]}, {62, 
       FormBox["\"\"", TraditionalForm]}, {63, 
       FormBox["\"\"", TraditionalForm]}, {64, 
       FormBox["\"\"", TraditionalForm]}, {65, 
       FormBox["\"\"", TraditionalForm]}, {66, 
       FormBox["\"\"", TraditionalForm]}, {67, 
       FormBox["\"\"", TraditionalForm]}, {68, 
       FormBox["\"\"", TraditionalForm]}, {69, 
       FormBox["\"\"", TraditionalForm]}, {70, 
       FormBox["\"\"", TraditionalForm]}, {71, 
       FormBox["\"\"", TraditionalForm]}, {72, 
       FormBox["\"\"", TraditionalForm]}, {73, 
       FormBox["\"\"", TraditionalForm]}, {74, 
       FormBox["\"\"", TraditionalForm]}, {75, 
       FormBox["\"\"", TraditionalForm]}, {76, 
       FormBox["\"\"", TraditionalForm]}, {77, 
       FormBox["\"\"", TraditionalForm]}, {78, 
       FormBox["\"\"", TraditionalForm]}, {79, 
       FormBox["\"\"", TraditionalForm]}, {80, 
       FormBox["\"\"", TraditionalForm]}, {81, 
       FormBox["\"\"", TraditionalForm]}, {82, 
       FormBox["\"\"", TraditionalForm]}, {83, 
       FormBox["\"\"", TraditionalForm]}, {84, 
       FormBox["\"\"", TraditionalForm]}, {85, 
       FormBox["\"\"", TraditionalForm]}, {86, 
       FormBox["\"\"", TraditionalForm]}, {87, 
       FormBox["\"\"", TraditionalForm]}, {88, 
       FormBox["\"\"", TraditionalForm]}, {89, 
       FormBox["\"\"", TraditionalForm]}, {90, 
       FormBox["\"\"", TraditionalForm]}, {91, 
       FormBox["\"\"", TraditionalForm]}, {92, 
       FormBox["\"\"", TraditionalForm]}, {93, 
       FormBox["\"\"", TraditionalForm]}, {94, 
       FormBox["\"\"", TraditionalForm]}, {95, 
       FormBox["\"\"", TraditionalForm]}, {96, 
       FormBox["\"\"", TraditionalForm]}, {97, 
       FormBox["\"\"", TraditionalForm]}, {98, 
       FormBox["\"\"", TraditionalForm]}, {99, 
       FormBox["\"\"", TraditionalForm]}, {100, 
       FormBox["\"\"", TraditionalForm]}}}, {{{2, 
       FormBox["2", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["3", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["4", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["5", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["6", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["7", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["8", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["9", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["10", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["11", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["12", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["13", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["14", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["15", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["16", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["17", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["18", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["19", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox["\"\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{{{
      GrayLevel[0.9], 
      RectangleBox[{10.561453473142157`, -10000}, {
       12.222494362608364`, 10000}]}, {
      GrayLevel[0.8], 
      RectangleBox[{12.222494362608364`, -10000}, {
       14.334981351900138`, 10000}]}, {
      GrayLevel[0.7], 
      RectangleBox[{14.334981351900138`, -10000}, {17, 10000}]}}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.636847125276335*^9, 3.636847466767321*^9, 
  3.646456148217771*^9, 3.646475893028215*^9}]
}, Open  ]],

Cell["\<\
Draw the plot for the atmospheric mass squared difference (on a linear scale)\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]m2atm", "[", "t", "]"}], "*", 
      RowBox[{"10", "^", "3"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\)(\[Mu]/GeV)\>\"", ",", 
        "\"\<\!\(\*SubsuperscriptBox[\(\[CapitalDelta]m\), \(atm\), \(2\)]\) \
[\!\(\*SuperscriptBox[\(10\), \
\(-3\)]\)\[ThinSpace]\!\(\*SuperscriptBox[\(eV\), \(2\)]\)]\>\""}], "}"}]}], 
     ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGELogTicksLabeled", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "*", "0.2"}], ",", 
            RowBox[{"PaddedForm", "[", 
             RowBox[{
              RowBox[{"i", "*", "0.2"}], ",", 
              RowBox[{"{", 
               RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "50"}], ",", "50"}], "}"}]}], "]"}], ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "*", "0.2"}], ",", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "50"}], "}"}]}], "]"}]}], "}"}]}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", "ShadowEFT", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.435655660381*^9, 3.435655690904253*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV0Hk81Nsfx/Ex3zEztu+XG0XKnvWLKVtx8b6iYdxStJHthqJGpKiEkrRZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{2., 2.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*SubsuperscriptBox[\\(\[CapitalDelta]m\\), \\(atm\\), \
\\(2\\)]\\) [\\!\\(\\*SuperscriptBox[\\(10\\), \\(-3\\)]\\)\[ThinSpace]\\!\\(\
\\*SuperscriptBox[\\(eV\\), \\(2\\)]\\)]\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(log\\), \\(10\\)]\\)(\[Mu]/GeV)\"", 
      TraditionalForm], None}},
  FrameTicks->{{{{-10., 
       FormBox[
        TagBox[
         InterpretationBox["\"-10.0\"", -10., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-9.8, 
       FormBox[
        TagBox[
         InterpretationBox["\"-9.8\"", -9.8, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-9.600000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-9.6\"", -9.600000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-9.4, 
       FormBox[
        TagBox[
         InterpretationBox["\"-9.4\"", -9.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-9.200000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-9.2\"", -9.200000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-9., 
       FormBox[
        TagBox[
         InterpretationBox["\"-9.0\"", -9., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-8.8, 
       FormBox[
        TagBox[
         InterpretationBox["\"-8.8\"", -8.8, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-8.6, 
       FormBox[
        TagBox[
         InterpretationBox["\"-8.6\"", -8.6, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-8.4, 
       FormBox[
        TagBox[
         InterpretationBox["\"-8.4\"", -8.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-8.200000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-8.2\"", -8.200000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-8., 
       FormBox[
        TagBox[
         InterpretationBox["\"-8.0\"", -8., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-7.800000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-7.8\"", -7.800000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-7.6000000000000005`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-7.6\"", -7.6000000000000005`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-7.4, 
       FormBox[
        TagBox[
         InterpretationBox["\"-7.4\"", -7.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-7.2, 
       FormBox[
        TagBox[
         InterpretationBox["\"-7.2\"", -7.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-7., 
       FormBox[
        TagBox[
         InterpretationBox["\"-7.0\"", -7., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-6.800000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-6.8\"", -6.800000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-6.6000000000000005`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-6.6\"", -6.6000000000000005`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-6.4, 
       FormBox[
        TagBox[
         InterpretationBox["\"-6.4\"", -6.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-6.2, 
       FormBox[
        TagBox[
         InterpretationBox["\"-6.2\"", -6.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-6., 
       FormBox[
        TagBox[
         InterpretationBox["\"-6.0\"", -6., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-5.800000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-5.8\"", -5.800000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-5.6000000000000005`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-5.6\"", -5.6000000000000005`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-5.4, 
       FormBox[
        TagBox[
         InterpretationBox["\"-5.4\"", -5.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-5.2, 
       FormBox[
        TagBox[
         InterpretationBox["\"-5.2\"", -5.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-5., 
       FormBox[
        TagBox[
         InterpretationBox["\"-5.0\"", -5., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-4.800000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-4.8\"", -4.800000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-4.6000000000000005`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-4.6\"", -4.6000000000000005`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-4.4, 
       FormBox[
        TagBox[
         InterpretationBox["\"-4.4\"", -4.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-4.2, 
       FormBox[
        TagBox[
         InterpretationBox["\"-4.2\"", -4.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-4., 
       FormBox[
        TagBox[
         InterpretationBox["\"-4.0\"", -4., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-3.8000000000000003`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-3.8\"", -3.8000000000000003`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-3.6, 
       FormBox[
        TagBox[
         InterpretationBox["\"-3.6\"", -3.6, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-3.4000000000000004`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-3.4\"", -3.4000000000000004`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-3.2, 
       FormBox[
        TagBox[
         InterpretationBox["\"-3.2\"", -3.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-3., 
       FormBox[
        TagBox[
         InterpretationBox["\"-3.0\"", -3., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-2.8000000000000003`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-2.8\"", -2.8000000000000003`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-2.6, 
       FormBox[
        TagBox[
         InterpretationBox["\"-2.6\"", -2.6, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-2.4000000000000004`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-2.4\"", -2.4000000000000004`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-2.2, 
       FormBox[
        TagBox[
         InterpretationBox["\"-2.2\"", -2.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-2., 
       FormBox[
        TagBox[
         InterpretationBox["\"-2.0\"", -2., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-1.8, 
       FormBox[
        TagBox[
         InterpretationBox["\"-1.8\"", -1.8, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-1.6, 
       FormBox[
        TagBox[
         InterpretationBox["\"-1.6\"", -1.6, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-1.4000000000000001`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-1.4\"", -1.4000000000000001`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-1.2000000000000002`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-1.2\"", -1.2000000000000002`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-1., 
       FormBox[
        TagBox[
         InterpretationBox["\"-1.0\"", -1., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-0.8, 
       FormBox[
        TagBox[
         InterpretationBox["\"-0.8\"", -0.8, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-0.6000000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\"-0.6\"", -0.6000000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-0.4, 
       FormBox[
        TagBox[
         InterpretationBox["\"-0.4\"", -0.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {-0.2, 
       FormBox[
        TagBox[
         InterpretationBox["\"-0.2\"", -0.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {0., 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.0\"", 0., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {0.2, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.2\"", 0.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {0.4, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.4\"", 0.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {0.6000000000000001, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 0.6\"", 0.6000000000000001, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {0.8, 
       FormBox[
        TagBox[
         InterpretationBox["\" 0.8\"", 0.8, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {1., 
       FormBox[
        TagBox[
         InterpretationBox["\" 1.0\"", 1., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {1.2000000000000002`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 1.2\"", 1.2000000000000002`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {1.4000000000000001`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 1.4\"", 1.4000000000000001`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {1.6, 
       FormBox[
        TagBox[
         InterpretationBox["\" 1.6\"", 1.6, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {1.8, 
       FormBox[
        TagBox[
         InterpretationBox["\" 1.8\"", 1.8, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {2., 
       FormBox[
        TagBox[
         InterpretationBox["\" 2.0\"", 2., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {2.2, 
       FormBox[
        TagBox[
         InterpretationBox["\" 2.2\"", 2.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {2.4000000000000004`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 2.4\"", 2.4000000000000004`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {2.6, 
       FormBox[
        TagBox[
         InterpretationBox["\" 2.6\"", 2.6, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {2.8000000000000003`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 2.8\"", 2.8000000000000003`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {3., 
       FormBox[
        TagBox[
         InterpretationBox["\" 3.0\"", 3., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {3.2, 
       FormBox[
        TagBox[
         InterpretationBox["\" 3.2\"", 3.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {3.4000000000000004`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 3.4\"", 3.4000000000000004`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {3.6, 
       FormBox[
        TagBox[
         InterpretationBox["\" 3.6\"", 3.6, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {3.8000000000000003`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 3.8\"", 3.8000000000000003`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {4., 
       FormBox[
        TagBox[
         InterpretationBox["\" 4.0\"", 4., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {4.2, 
       FormBox[
        TagBox[
         InterpretationBox["\" 4.2\"", 4.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {4.4, 
       FormBox[
        TagBox[
         InterpretationBox["\" 4.4\"", 4.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {4.6000000000000005`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 4.6\"", 4.6000000000000005`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {4.800000000000001, 
       FormBox[
        TagBox[
         InterpretationBox["\" 4.8\"", 4.800000000000001, AutoDelete -> True],
          PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {5., 
       FormBox[
        TagBox[
         InterpretationBox["\" 5.0\"", 5., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {5.2, 
       FormBox[
        TagBox[
         InterpretationBox["\" 5.2\"", 5.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {5.4, 
       FormBox[
        TagBox[
         InterpretationBox["\" 5.4\"", 5.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {5.6000000000000005`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 5.6\"", 5.6000000000000005`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {5.800000000000001, 
       FormBox[
        TagBox[
         InterpretationBox["\" 5.8\"", 5.800000000000001, AutoDelete -> True],
          PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {6., 
       FormBox[
        TagBox[
         InterpretationBox["\" 6.0\"", 6., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {6.2, 
       FormBox[
        TagBox[
         InterpretationBox["\" 6.2\"", 6.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {6.4, 
       FormBox[
        TagBox[
         InterpretationBox["\" 6.4\"", 6.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {6.6000000000000005`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 6.6\"", 6.6000000000000005`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {6.800000000000001, 
       FormBox[
        TagBox[
         InterpretationBox["\" 6.8\"", 6.800000000000001, AutoDelete -> True],
          PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {7., 
       FormBox[
        TagBox[
         InterpretationBox["\" 7.0\"", 7., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {7.2, 
       FormBox[
        TagBox[
         InterpretationBox["\" 7.2\"", 7.2, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {7.4, 
       FormBox[
        TagBox[
         InterpretationBox["\" 7.4\"", 7.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {7.6000000000000005`, 
       FormBox[
        TagBox[
         InterpretationBox[
         "\" 7.6\"", 7.6000000000000005`, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {7.800000000000001, 
       FormBox[
        TagBox[
         InterpretationBox["\" 7.8\"", 7.800000000000001, AutoDelete -> True],
          PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {8., 
       FormBox[
        TagBox[
         InterpretationBox["\" 8.0\"", 8., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {8.200000000000001, 
       FormBox[
        TagBox[
         InterpretationBox["\" 8.2\"", 8.200000000000001, AutoDelete -> True],
          PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {8.4, 
       FormBox[
        TagBox[
         InterpretationBox["\" 8.4\"", 8.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {8.6, 
       FormBox[
        TagBox[
         InterpretationBox["\" 8.6\"", 8.6, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {8.8, 
       FormBox[
        TagBox[
         InterpretationBox["\" 8.8\"", 8.8, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {9., 
       FormBox[
        TagBox[
         InterpretationBox["\" 9.0\"", 9., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {9.200000000000001, 
       FormBox[
        TagBox[
         InterpretationBox["\" 9.2\"", 9.200000000000001, AutoDelete -> True],
          PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {9.4, 
       FormBox[
        TagBox[
         InterpretationBox["\" 9.4\"", 9.4, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {9.600000000000001, 
       FormBox[
        TagBox[
         InterpretationBox["\" 9.6\"", 9.600000000000001, AutoDelete -> True],
          PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {9.8, 
       FormBox[
        TagBox[
         InterpretationBox["\" 9.8\"", 9.8, AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}, {10., 
       FormBox[
        TagBox[
         InterpretationBox["\" 10.0\"", 10., AutoDelete -> True], 
         PaddedForm[#, {2, 1}]& ], TraditionalForm]}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {0.2, 
       FormBox["\"\"", TraditionalForm]}, {0.4, 
       FormBox["\"\"", TraditionalForm]}, {0.6000000000000001, 
       FormBox["\"\"", TraditionalForm]}, {0.8, 
       FormBox["\"\"", TraditionalForm]}, {1., 
       FormBox["\"\"", TraditionalForm]}, {1.2000000000000002`, 
       FormBox["\"\"", TraditionalForm]}, {1.4000000000000001`, 
       FormBox["\"\"", TraditionalForm]}, {1.6, 
       FormBox["\"\"", TraditionalForm]}, {1.8, 
       FormBox["\"\"", TraditionalForm]}, {2., 
       FormBox["\"\"", TraditionalForm]}, {2.2, 
       FormBox["\"\"", TraditionalForm]}, {2.4000000000000004`, 
       FormBox["\"\"", TraditionalForm]}, {2.6, 
       FormBox["\"\"", TraditionalForm]}, {2.8000000000000003`, 
       FormBox["\"\"", TraditionalForm]}, {3., 
       FormBox["\"\"", TraditionalForm]}, {3.2, 
       FormBox["\"\"", TraditionalForm]}, {3.4000000000000004`, 
       FormBox["\"\"", TraditionalForm]}, {3.6, 
       FormBox["\"\"", TraditionalForm]}, {3.8000000000000003`, 
       FormBox["\"\"", TraditionalForm]}, {4., 
       FormBox["\"\"", TraditionalForm]}, {4.2, 
       FormBox["\"\"", TraditionalForm]}, {4.4, 
       FormBox["\"\"", TraditionalForm]}, {4.6000000000000005`, 
       FormBox["\"\"", TraditionalForm]}, {4.800000000000001, 
       FormBox["\"\"", TraditionalForm]}, {5., 
       FormBox["\"\"", TraditionalForm]}, {5.2, 
       FormBox["\"\"", TraditionalForm]}, {5.4, 
       FormBox["\"\"", TraditionalForm]}, {5.6000000000000005`, 
       FormBox["\"\"", TraditionalForm]}, {5.800000000000001, 
       FormBox["\"\"", TraditionalForm]}, {6., 
       FormBox["\"\"", TraditionalForm]}, {6.2, 
       FormBox["\"\"", TraditionalForm]}, {6.4, 
       FormBox["\"\"", TraditionalForm]}, {6.6000000000000005`, 
       FormBox["\"\"", TraditionalForm]}, {6.800000000000001, 
       FormBox["\"\"", TraditionalForm]}, {7., 
       FormBox["\"\"", TraditionalForm]}, {7.2, 
       FormBox["\"\"", TraditionalForm]}, {7.4, 
       FormBox["\"\"", TraditionalForm]}, {7.6000000000000005`, 
       FormBox["\"\"", TraditionalForm]}, {7.800000000000001, 
       FormBox["\"\"", TraditionalForm]}, {8., 
       FormBox["\"\"", TraditionalForm]}, {8.200000000000001, 
       FormBox["\"\"", TraditionalForm]}, {8.4, 
       FormBox["\"\"", TraditionalForm]}, {8.6, 
       FormBox["\"\"", TraditionalForm]}, {8.8, 
       FormBox["\"\"", TraditionalForm]}, {9., 
       FormBox["\"\"", TraditionalForm]}, {9.200000000000001, 
       FormBox["\"\"", TraditionalForm]}, {9.4, 
       FormBox["\"\"", TraditionalForm]}, {9.600000000000001, 
       FormBox["\"\"", TraditionalForm]}, {9.8, 
       FormBox["\"\"", TraditionalForm]}, {10., 
       FormBox["\"\"", TraditionalForm]}}}, {{{2, 
       FormBox["2", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["3", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["4", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["5", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["6", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["7", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["8", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["9", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["10", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["11", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["12", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["13", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["14", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["15", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["16", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["17", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["18", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["19", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox["\"\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{{{
      GrayLevel[0.9], 
      RectangleBox[{10.561453473142157`, -10000}, {
       12.222494362608364`, 10000}]}, {
      GrayLevel[0.8], 
      RectangleBox[{12.222494362608364`, -10000}, {
       14.334981351900138`, 10000}]}, {
      GrayLevel[0.7], 
      RectangleBox[{14.334981351900138`, -10000}, {17, 10000}]}}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.63684712581448*^9, 3.636847467341304*^9, 
  3.6464561495243464`*^9, 3.646475893902885*^9}]
}, Open  ]],

Cell["RG change of the mass squared differences:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\
\), \(2\)], \(sol\)]\) is:     \!\(\*SubscriptBox[SuperscriptBox[\(\
\[CapitalDelta]m\), \(2\)], \(sol\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\))-\
\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \(2\)], \(sol\)]\)(\!\
\(\*SubscriptBox[\(M\), \(Z\)]\)) = \>\"", ",", 
    RowBox[{
     RowBox[{"\[CapitalDelta]m2sol", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"\[CapitalDelta]m2sol", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", 
    "\"\< \!\(\*SuperscriptBox[\(eV\), \(2\)]\)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The RG change of \!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\
\), \(2\)], \(atm\)]\) is:     \!\(\*SubscriptBox[SuperscriptBox[\(\
\[CapitalDelta]m\), \(2\)], \(atm\)]\)(\!\(\*SubscriptBox[\(M\), \(GUT\)]\))-\
\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \(2\)], \(atm\)]\)(\!\
\(\*SubscriptBox[\(M\), \(Z\)]\)) = \>\"", ",", 
    RowBox[{
     RowBox[{"\[CapitalDelta]m2atm", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "GUT"}], "]"}], "]"}], "-", 
     RowBox[{"\[CapitalDelta]m2atm", "[", 
      RowBox[{"Log", "[", 
       RowBox[{"10", ",", "MZ"}], "]"}], "]"}]}], ",", 
    "\"\< \!\(\*SuperscriptBox[\(eV\), \(2\)]\)\>\""}], "]"}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[SuperscriptBox[\\(\
\[CapitalDelta]m\\), \\(2\\)], \\(sol\\)]\\) is:     \
\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalDelta]m\\), \\(2\\)], \\(sol\
\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalDelta]m\\), \
\\(2\\)], \\(sol\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", "0.00008281272704689866`", 
   "\[InvisibleSpace]", "\<\" \\!\\(\\*SuperscriptBox[\\(eV\\), \\(2\\)]\\)\"\
\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \
\(2\)], \(sol\)]\) is:     \
\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \(2\)], \(sol\)]\)(\!\
\(\*SubscriptBox[\(M\), \(GUT\)]\))-\!\(\*SubscriptBox[SuperscriptBox[\(\
\[CapitalDelta]m\), \(2\)], \(sol\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = \
", 0.00008281272704689866, " \!\(\*SuperscriptBox[\(eV\), \(2\)]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.63684712587848*^9, 3.6368474673944283`*^9, 
  3.646456149730103*^9, 3.6464758940037413`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The RG change of \\!\\(\\*SubscriptBox[SuperscriptBox[\\(\
\[CapitalDelta]m\\), \\(2\\)], \\(atm\\)]\\) is:     \
\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalDelta]m\\), \\(2\\)], \\(atm\
\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \
\\(GUT\\)]\\))-\\!\\(\\*SubscriptBox[SuperscriptBox[\\(\[CapitalDelta]m\\), \
\\(2\\)], \\(atm\\)]\\)(\\!\\(\\*SubscriptBox[\\(M\\), \\(Z\\)]\\)) = \"\>", 
   "\[InvisibleSpace]", "0.0019050199501962233`", 
   "\[InvisibleSpace]", "\<\" \\!\\(\\*SuperscriptBox[\\(eV\\), \\(2\\)]\\)\"\
\>"}],
  SequenceForm[
  "The RG change of \!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \
\(2\)], \(atm\)]\) is:     \
\!\(\*SubscriptBox[SuperscriptBox[\(\[CapitalDelta]m\), \(2\)], \(atm\)]\)(\!\
\(\*SubscriptBox[\(M\), \(GUT\)]\))-\!\(\*SubscriptBox[SuperscriptBox[\(\
\[CapitalDelta]m\), \(2\)], \(atm\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)) = \
", 0.0019050199501962233`, " \!\(\*SuperscriptBox[\(eV\), \(2\)]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.63684712587848*^9, 3.6368474673944283`*^9, 
  3.646456149730103*^9, 3.646475894009172*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CP asymmetry in leptogenesis ", "Section"],

Cell[TextData[{
 "In order to calculate the CP asymmetry, the Majorana mass matrix of the \
right-handed and the left-handed neutrinos and the neutrino Yukawa couplings \
are needed. The returned matrices are the matrices which are valid at the \
given scale pScale. RGEM\[Nu]r and RGEY\[Nu] can also be used, but the \
returned matrices also contain the values of the right-handed neutrinos which \
are already integrated out.\n\nIn the following, the CP asymmetry (MSSM) in \
thermal leptogenesis in the limit ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["M", "1"], 
     RowBox[{"<<", " ", 
      SubscriptBox["M", "2"]}]}], ",", 
    SubscriptBox["M", "3"]}], TraditionalForm]]],
 "is calculated. If you want to calculate the CP asymmetry in a different \
scenario, you have to change the formula appropiately."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]", "[", "pScale_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lM", ",", "lY", ",", "lm", ",", "lvev"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"right", "-", 
       RowBox[{"handed", " ", "neutrino", " ", "mass", " ", "matrix"}]}], " ",
       "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"lM", "=", 
       RowBox[{"RGEGetSolution", "[", 
        RowBox[{"pScale", ",", "RGERawM\[Nu]r", ",", "1"}], "]"}]}], ";", " ",
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"neutrino", " ", "Yukawa", " ", "couplings", " ", "matrix"}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"lY", "=", 
       RowBox[{"RGEGetSolution", "[", 
        RowBox[{"pScale", ",", "RGERawY\[Nu]", ",", "1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"light", " ", "neutrino", " ", "mass", " ", "matrix"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"lm", "=", 
       RowBox[{
        RowBox[{"RGEGetSolution", "[", 
         RowBox[{"pScale", ",", "RGEM\[Nu]", ",", "1"}], "]"}], "*", 
        RowBox[{"10", "^", 
         RowBox[{"-", "9"}]}]}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"change", " ", "to", " ", "the", " ", "basis"}], ",", " ", 
        RowBox[{"where", " ", "M", " ", "is", " ", "diagonal"}]}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"lM", ",", "lY"}], "}"}], "=", 
       RowBox[{"RGERotateM", "[", 
        RowBox[{"lM", ",", "lY"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "the", " ", "mass", " ", "of", " ", "the", " ", "lightest", " ", 
         "right"}], "-", 
        RowBox[{"handed", " ", "neutrino"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"lM1", "=", 
       RowBox[{"lM", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "the", " ", "Yukawa", " ", "couplings", " ", "of", " ", "the", " ", 
         "lightest", " ", "right"}], "-", 
        RowBox[{"handed", " ", "neutrino"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"lY1", "=", 
       RowBox[{"lY", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"lvev", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"N", "[", 
             RowBox[{"RGEvEW", "*", 
              RowBox[{"RGEtan\[Beta]", "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"1", "+", 
                 RowBox[{"RGEtan\[Beta]", "^", "2"}]}], "]"}]}]}], "]"}], "/", 
            RowBox[{"Sqrt", "[", "2", "]"}]}], ")"}], "/.", 
          RowBox[{
           RowBox[{"RGEGetOptions", "[", "\"\<MSSM\>\"", "]"}], 
           "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], "/.", 
        
        RowBox[{
         RowBox[{"RGEGetModelOptions", "[", "\"\<MSSM\>\"", "]"}], 
         "\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"CP", " ", "asymmetry"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"leps", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"3", "/", "8"}], "/", "\[Pi]"}], "*", 
        RowBox[{"lM1", "/", 
         RowBox[{"lvev", "^", "2"}]}], "*", 
        RowBox[{
         RowBox[{"Im", "[", 
          RowBox[{"(", 
           RowBox[{"lY1", ".", 
            RowBox[{"Conjugate", "[", "lm", "]"}], ".", "lY1"}], ")"}], "]"}],
          "/", 
         RowBox[{"(", 
          RowBox[{"lY1", ".", 
           RowBox[{"Conjugate", "[", "lY1", "]"}]}], ")"}]}]}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", "leps", "]"}], ";"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGEGetTransitions", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Infinity]", ",", "\<\"MSSM\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"RGEtan\[Beta]", "\[Rule]", "50"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.162625661103112`*^14", ",", "\<\"MSSM\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RGEAutoGenerated", "\[Rule]", "True"}], ",", 
       RowBox[{"RGEIntegratedOut", "\[Rule]", "1"}], ",", 
       RowBox[{"RGEtan\[Beta]", "\[Rule]", "50"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6691461405955383`*^12", ",", "\<\"MSSM\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RGEAutoGenerated", "\[Rule]", "True"}], ",", 
       RowBox[{"RGEIntegratedOut", "\[Rule]", "2"}], ",", 
       RowBox[{"RGEtan\[Beta]", "\[Rule]", "50"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.6429522028436714`*^10", ",", "\<\"MSSM0N\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RGEAutoGenerated", "\[Rule]", "True"}], ",", 
       RowBox[{"RGEtan\[Beta]", "\[Rule]", "50"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "\<\"SM0N\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"RGEAutoGenerated", "\[Rule]", "\<\"SM\"\>"}], "}"}]}], "}"}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.636847125947072*^9, 3.636847467437077*^9, 
  3.6464561498586683`*^9, 3.646475894064805*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Epsilon]", "[", 
  RowBox[{
   RowBox[{"RGEGetTransitions", "[", "]"}], "\[LeftDoubleBracket]", 
   RowBox[{"4", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"3.3806431995516963`*^-10", "+", 
  RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{3.636847125978827*^9, 3.63684746746513*^9, 
  3.646456149987809*^9, 3.646475894109614*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"However", ",", 
  RowBox[{
  "the", " ", "CP", " ", "asymmetry", " ", "in", " ", "thermal", " ", 
   "leptogenesis", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"in", " ", "the", " ", "limit", " ", 
      SubscriptBox["M", 
       RowBox[{"1", " "}]], 
      RowBox[{"<<", " ", 
       SubscriptBox["M", "2"]}]}], ",", 
     SubscriptBox["M", "3"]}], ")"}], " ", "is", " ", "much", " ", "easier", 
   " ", "obtained", " ", "directly", " ", "by", " ", 
   RowBox[{"RGEGetSolution", "."}]}]}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGEGetSolution", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"RGEGetTransitions", "[", "]"}], "\[LeftDoubleBracket]", 
    RowBox[{"4", ",", "1"}], "\[RightDoubleBracket]"}], ",", "RGE\[Epsilon]1",
    ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"3.3806431995516963`*^-10", "+", 
  RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{3.636847126009606*^9, 3.6368474674930067`*^9, 
  3.6464561503763866`*^9, 3.646475894232853*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"RGEGetSolution", "[", 
      RowBox[{
       RowBox[{"10", "^", "t"}], ",", "RGE\[Epsilon]1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{
          RowBox[{"RGEGetTransitions", "[", "]"}], "\[LeftDoubleBracket]", 
          RowBox[{"4", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], ",", 
       "tmax"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\)(\[Mu]/GeV)\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(\[Epsilon]\), \(1\)]\)\>\""}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGELogTicksLabeled", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", "Automatic", ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", "Automatic"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", "ShadowEFT", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.435655668026875*^9, 3.435655697375855*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV02lUlFUYB/ABFFmygVPjkEGs7zDzzvsyIwSEceE5ESQM2ylZRCodZTEE
RcFBFmMREDAD8QgnDBNZFJQ1iCQFFBQwVPCwCgLhkX0RgzsRHrt9uOee37fn
uf//NZYf+TJIlcPhfE7O//f0rPfgCUMKND7s8nf7FCM7u9yEv1gKzBaSt5XZ
Y5SZ3mfiaU9BXm3cKMcBI9YsIJzaQ8EsTy+9AjCiKHO9yjwKXNw7lW4uGCl/
Xnqh20uBARVU6S/DyOm6LNZbWwCQ6ttm4I3RZ/Fh1CFXAbiNOQTzfDDSf5C2
EpgigJEiRWjaHozKh4L66LsCUA8ET6NvMKo+NZj49K0AWkPCGsLlGGUXuHj6
2ZnD+qL3jGMwRmaJMTvqFeZQmBM6Z/EdRrkjJTaLNeZgJW9LuBaOUezD4E2q
c+bgG5hmOHEUI17y3NSSUAiZ/ipX6SiyX3XYQqNcCDdmrP7UVGBUV1qlEXhF
CMWmcercWIx8JOnzQ8+F4Gr36OJgPEY9koAVSz0R7JrQLoHvMVJRLm8N9hXB
qmCstTQJI+1PUmRR2SIY3R6nWZOCUafjUGHgYxEElxnIqlIx4gzfvWW4lYb0
lI2WsHSMdOfLlLddaKBGMu8NnMHob/94k/UgGtYLzArPZGDU3+7tbpNKQ0Et
/x1xJkaliyZb9hXRcOB1xvV64hP81daMZhpaVqbLrbIwStbUnTAaoUHspP2q
iPjcvwynUUnDaFykjvpZjKJ6aPoPvhhSc+L6DxAHlAl3t9iIgS8pda4jZu3M
uLVfiWGmfP3IMjHnoWHX1aNiUB3P4xr/gNFNePOjarYYmOHN578gDmgY9tlf
JQZ1vSK3b4mdVlUS2UdiuPRGQYcSMx+Lyv+ZF8PTvNAmObGqxDOoTpOBnazf
HW/iIdFxo3ABAxfnTZ0siTM1Yl/mOjNw+VgXV41451TijVsHGXjQVqbfTuYZ
TEpVe5zEwHRT/6sE4mj9zIDJQgaonoAxEbFX4iAvqImB4m43vxmyv+iFoOfl
AAP51Vrmt4lHxH55fWsMNEcP8BKJs4+nf93GY6Hp3cO+1sQ7FPW//mLJgrJr
r/0ked/e2EntBC8WVq0r2FRiD/nr8PsRLFh5qFTpEne4qj3hnmPhtCKLl03y
ki7o3HOpYMHXeMxTizg/+6OGhA4WdEdzJDEk34lD3Qfvq1hApNdGozXJ/7kW
iGYcLaB7yf7ZFdKPetNK7tRJC+A7XB5dJf2BTePazY0WUNqy74NF0i8nRcmT
yDUL2K1cf9ZA+mcsD/7trUQCW37alnssgfT3/bm6kAgJ8Isrd7WT/ho6hvWW
X5MA23b+rE4MRmobp37vmJDAzQJZsm002QfEe8e5Urhgu995OhKjtDsXZjsZ
KeRvnsi6FEHyf295+4K9FGbcfaVVhzE6GSKT6XhIQbpmW11D/tt/eUP8FA==

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{11., 3.38*^-10},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \\(1\\)]\\)\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(log\\), \\(10\\)]\\)(\[Mu]/GeV)\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {{{2, 
       FormBox["2", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["3", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["4", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["5", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["6", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["7", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["8", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["9", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["10", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["11", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["12", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["13", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["14", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["15", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["16", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["17", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["18", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["19", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox["\"\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{{{
      GrayLevel[0.9], 
      RectangleBox[{10.561453473142157`, -10000}, {
       12.222494362608364`, 10000}]}, {
      GrayLevel[0.8], 
      RectangleBox[{12.222494362608364`, -10000}, {
       14.334981351900138`, 10000}]}, {
      GrayLevel[0.7], 
      RectangleBox[{14.334981351900138`, -10000}, {17, 10000}]}}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.636847126177956*^9, 3.636847467659504*^9, 
  3.6464561515729227`*^9, 3.646475894455982*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Effective", " ", "neutrino", " ", "mass", 
  "\"\<\!\(\*SubscriptBox[OverscriptBox[\(m\), \(~\)], \(1\)]\)\>\"", 
  " "}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"RGEGetSolution", "[", 
      RowBox[{
       RowBox[{"10", "^", "t"}], ",", "RGEM1Tilde"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{
          RowBox[{"RGEGetTransitions", "[", "]"}], "\[LeftDoubleBracket]", 
          RowBox[{"4", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], ",", 
       "tmax"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\)(\[Mu]/GeV)\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[OverscriptBox[\(m\), \(~\)], \(1\)]\) \
[eV]\>\""}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGELogTicksLabeled", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", "Automatic", ",", 
        RowBox[{"RGELogTicks", "[", 
         RowBox[{"2", ",", "19"}], "]"}], ",", "Automatic"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"{", "ShadowEFT", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.43565567109143*^9, 3.435655699340998*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV0ns01PkbB/ARSZFx3WiVxDAzPjPzZa1lf9rPUy4lFLVsxC42EhLpV9gu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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{11., 0.020020000000000003`},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(m\\), \\(~\\)], \\(1\\)]\\) \
[eV]\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(log\\), \\(10\\)]\\)(\[Mu]/GeV)\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {{{2, 
       FormBox["2", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["3", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["4", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["5", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["6", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["7", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["8", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["9", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["10", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["11", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["12", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["13", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["14", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["15", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["16", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["17", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["18", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["19", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}, {{2, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200], 2.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300], 2.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400], 2.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500], 2.6989700043360183`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600], 2.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700], 2.8450980400142565`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800], 2.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900], 2.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {3, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000], 3.301029995663981], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000], 3.4771212547196617`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000], 3.6020599913279616`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000], 3.6989700043360187`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000], 3.7781512503836425`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000], 3.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000], 3.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000], 3.9542425094393243`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {4, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000], 4.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000], 4.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000], 4.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000], 4.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000], 4.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000], 4.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000], 4.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000], 4.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {5, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000], 5.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000], 5.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000], 5.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000], 5.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000], 5.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000], 5.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000], 5.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000], 5.954242509439324], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {6, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000], 6.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000], 6.477121254719662], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000], 6.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000], 6.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000], 6.778151250383643], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000], 6.845098040014256], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000], 6.903089986991943], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000], 6.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {7, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000], 7.3010299956639795`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000], 7.477121254719661], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000], 7.602059991327962], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000], 7.698970004336018], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000], 7.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000], 7.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000], 7.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000], 7.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {8, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000], 8.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000], 8.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000], 8.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000], 8.698970004336019], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000], 8.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000], 8.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000], 8.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000], 8.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {9, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000], 9.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000], 9.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000], 9.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000], 9.698970004336017], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000], 9.778151250383642], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000], 9.845098040014255], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000], 9.903089986991942], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000], 9.954242509439323], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {10, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000], 10.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000], 10.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000], 10.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000], 10.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000], 10.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000], 10.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000], 10.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000], 10.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {11, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000], 11.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000], 11.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000], 11.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000], 11.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000], 11.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000], 11.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000], 11.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000], 11.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {12, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000], 12.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000], 12.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000], 12.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000], 12.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000], 12.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000], 12.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000], 12.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000], 12.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {13, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000], 13.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000], 13.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000], 13.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000], 13.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000], 13.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000], 13.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000], 13.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000], 13.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {14, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000], 14.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000], 14.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000], 14.602059991327959`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000], 14.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000], 14.778151250383642`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000], 14.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000], 14.903089986991942`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000], 14.954242509439322`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {15, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000], 15.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000], 15.477121254719659`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000], 15.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000], 15.698970004336017`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000], 15.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000], 15.845098040014255`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000], 15.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000], 15.954242509439323`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {16, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000], 16.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000], 16.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000], 16.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000], 16.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000], 16.778151250383644`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000], 16.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000], 16.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000], 16.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {17, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[200000000000000000], 17.30102999566398], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[300000000000000000], 17.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[400000000000000000], 17.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[500000000000000000], 17.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[600000000000000000], 17.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[700000000000000000], 17.845098040014257`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[800000000000000000], 17.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[900000000000000000], 17.954242509439325`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {18, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[2000000000000000000], 18.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[3000000000000000000], 18.477121254719663`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[4000000000000000000], 18.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[5000000000000000000], 18.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[6000000000000000000], 18.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[7000000000000000000], 18.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[8000000000000000000], 18.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[9000000000000000000], 18.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {19, 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[Log[10]^(-1) Log[20000000000000000000], 19.301029995663978`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[30000000000000000000], 19.47712125471966], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[40000000000000000000], 19.60205999132796], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[50000000000000000000], 19.698970004336015`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[60000000000000000000], 19.77815125038364], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[70000000000000000000], 19.845098040014253`], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[80000000000000000000], 19.90308998699194], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}, {
       NCache[Log[10]^(-1) Log[90000000000000000000], 19.95424250943932], 
       FormBox["\"\"", TraditionalForm], {0.00375, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->400,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox["\"\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{{{
      GrayLevel[0.9], 
      RectangleBox[{10.561453473142157`, -10000}, {
       12.222494362608364`, 10000}]}, {
      GrayLevel[0.8], 
      RectangleBox[{12.222494362608364`, -10000}, {
       14.334981351900138`, 10000}]}, {
      GrayLevel[0.7], 
      RectangleBox[{14.334981351900138`, -10000}, {17, 10000}]}}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6368471263493433`*^9, 3.636847467833156*^9, 
  3.646456152634963*^9, 3.646475894784768*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{956, 1041},
WindowMargins->{{Automatic, 0}, {Automatic, 18}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"10.0 for Linux x86 (64-bit) (December 4, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 42, 0, 90, "Title"],
Cell[612, 24, 157, 3, 51, "Text"],
Cell[772, 29, 699, 17, 121, "Input"],
Cell[1474, 48, 190, 5, 55, "Input"],
Cell[1667, 55, 262, 7, 55, "Input"],
Cell[1932, 64, 153, 3, 31, "Text"],
Cell[2088, 69, 74, 2, 32, "Input"],
Cell[CellGroupData[{
Cell[2187, 75, 42, 0, 64, "Section"],
Cell[2232, 77, 150, 3, 51, "Text"],
Cell[2385, 82, 121, 2, 32, "Input"],
Cell[2509, 86, 445, 11, 55, "Input"],
Cell[2957, 99, 488, 12, 72, "Text"],
Cell[3448, 113, 4220, 108, 561, "Input"],
Cell[7671, 223, 106, 3, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7814, 231, 24, 0, 64, "Section"],
Cell[CellGroupData[{
Cell[7863, 235, 33, 0, 43, "Subsection"],
Cell[7899, 237, 38, 0, 31, "Text"],
Cell[7940, 239, 370, 11, 77, "Input"],
Cell[8313, 252, 59, 0, 31, "Text"],
Cell[8375, 254, 4307, 121, 517, "Input"],
Cell[12685, 377, 158, 4, 51, "Text"],
Cell[12846, 383, 5133, 137, 429, "Input"],
Cell[17982, 522, 43, 0, 30, "Text"],
Cell[18028, 524, 608, 17, 81, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18673, 546, 60, 0, 44, "Subsection"],
Cell[CellGroupData[{
Cell[18758, 550, 62, 1, 32, "Input"],
Cell[18823, 553, 722, 15, 43, "Print"]
}, Open  ]],
Cell[19560, 571, 45, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[19630, 575, 2669, 74, 196, "Input"],
Cell[CellGroupData[{
Cell[22324, 653, 524, 11, 23, "Print"],
Cell[22851, 666, 529, 11, 23, "Print"],
Cell[23383, 679, 526, 11, 23, "Print"],
Cell[23912, 692, 671, 13, 23, "Print"],
Cell[24586, 707, 672, 13, 23, "Print"],
Cell[25261, 722, 503, 11, 23, "Print"],
Cell[25767, 735, 505, 11, 23, "Print"],
Cell[26275, 748, 500, 11, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26836, 766, 35, 0, 44, "Subsection"],
Cell[26874, 768, 51, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[26950, 772, 4124, 106, 319, "Input"],
Cell[31077, 880, 52060, 881, 299, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83174, 1766, 49, 0, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[83248, 1770, 1802, 44, 143, "Input"],
Cell[CellGroupData[{
Cell[85075, 1818, 882, 17, 23, "Print"],
Cell[85960, 1837, 886, 17, 23, "Print"],
Cell[86849, 1856, 882, 17, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[87804, 1881, 28, 0, 43, "Subsection"],
Cell[87835, 1883, 44, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[87904, 1887, 3977, 103, 319, "Input"],
Cell[91884, 1992, 50659, 858, 295, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142580, 2855, 49, 0, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[142654, 2859, 1756, 43, 121, "Input"],
Cell[CellGroupData[{
Cell[144435, 2906, 624, 13, 23, "Print"],
Cell[145062, 2921, 894, 18, 23, "Print"],
Cell[145959, 2941, 898, 18, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[146930, 2967, 28, 0, 43, "Subsection"],
Cell[CellGroupData[{
Cell[146983, 2971, 41, 0, 35, "Subsubsection"],
Cell[147027, 2973, 54, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[147106, 2977, 4343, 114, 363, "Input"],
Cell[151452, 3093, 61803, 1117, 292, "Output"]
}, Open  ]],
Cell[213270, 4213, 40, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[213335, 4217, 1699, 45, 143, "Input"],
Cell[CellGroupData[{
Cell[215059, 4266, 804, 16, 23, "Print"],
Cell[215866, 4284, 804, 16, 23, "Print"],
Cell[216673, 4302, 805, 16, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[217539, 4325, 49, 0, 35, "Subsubsection"],
Cell[217591, 4327, 95, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[217711, 4333, 3695, 96, 356, "Input"],
Cell[221409, 4431, 60139, 1046, 287, "Output"]
}, Open  ]],
Cell[281563, 5480, 95, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[281683, 5486, 2090, 53, 222, "Input"],
Cell[283776, 5541, 64171, 1214, 297, "Output"]
}, Open  ]],
Cell[347962, 6758, 103, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[348090, 6765, 2306, 59, 244, "Input"],
Cell[350399, 6826, 62968, 1196, 293, "Output"]
}, Open  ]],
Cell[413382, 8025, 58, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[413465, 8029, 1527, 34, 119, "Input"],
Cell[CellGroupData[{
Cell[415017, 8067, 1145, 20, 23, "Print"],
Cell[416165, 8089, 1142, 20, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[417392, 8118, 48, 0, 65, "Section"],
Cell[417443, 8120, 854, 18, 151, "Text"],
Cell[418300, 8140, 4401, 109, 605, "Input"],
Cell[CellGroupData[{
Cell[422726, 8253, 65, 1, 32, "Input"],
Cell[422794, 8256, 1378, 33, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[424209, 8294, 194, 4, 32, "Input"],
Cell[424406, 8300, 220, 4, 32, "Output"]
}, Open  ]],
Cell[424641, 8307, 529, 14, 54, "Text"],
Cell[CellGroupData[{
Cell[425195, 8325, 251, 6, 32, "Input"],
Cell[425449, 8333, 225, 4, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[425711, 8342, 1703, 41, 165, "Input"],
Cell[427417, 8385, 40704, 680, 269, "Output"]
}, Open  ]],
Cell[468136, 9068, 155, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[468316, 9075, 1741, 42, 200, "Input"],
Cell[470060, 9119, 41621, 694, 320, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
